<?php

/**
 * Course Category Icon Support
 */

add_action( 'course_category_add_form_fields', 'ep_taxonomy_add_icon_field', 20, 2 );
add_action( 'course_category_edit_form_fields', 'ep_taxonomy_edit_icon_field', 20, 2 );
add_action( 'edited_course_category', 'ep_save_taxonomy_icon', 10, 2 );  
add_action( 'create_course_category', 'ep_save_taxonomy_icon', 10, 2 );
add_filter( 'manage_edit-course_category_columns', 'ep_columns_head', 10, 3 );
add_filter( 'manage_course_category_custom_column', 'ep_columns_content_taxonomy', 10, 3 );
add_action( 'admin_enqueue_scripts', 'ep_course_category_icon_scripts_admin' );


/**
 * Icon scripts
 */

if( !function_exists('ep_course_category_icon_scripts_admin') ){
	function ep_course_category_icon_scripts_admin(){
		$screen = get_current_screen();
		if( $screen->id == 'edit-course_category' ){
			wp_enqueue_script( 'ep-fonticonpicker', get_template_directory_uri() . '/admin/assets/js/jquery.fonticonpicker.min.js', array('jquery'), '2.0', true );
			wp_enqueue_style( 'ep-fonticonpicker', get_template_directory_uri() . '/admin/assets/css/jquery.fonticonpicker.min.css', array(), '2.0' );
			wp_enqueue_style( 'ep-fonticonpicker-grey-theme', get_template_directory_uri() . '/admin/assets/css/jquery.fonticonpicker.grey.min.css', array(), '2.0' );
			wp_enqueue_style( 'font-awesoume', get_template_directory_uri() . '/assets/css/font-awesome.css', array(), '4.6.3' );
			wp_enqueue_style( 'themify-icons', get_template_directory_uri() . '/assets/css/themify-icons.css', array(), '1.0' );
			wp_enqueue_style( 'devicon-icons', get_template_directory_uri() . '/assets/css/devicon.min.css', array(), '1.0' );
		}
	}
}



/* Add term page */

if( !function_exists('ep_taxonomy_add_icon_field') ){
	function ep_taxonomy_add_icon_field() {
		?>
		<div class="form-field">
			<label for="ep_term_meta[ep_cat_icons]"><?php esc_html_e( 'Icon', 'wp-education' ); ?></label>
			<div class="ep-icon-picker-wrapper">
				<input type="text" name="ep_term_meta[ep_cat_icons]" id="ep-icon-picker" value="">
			</div>
			<p class="description"><?php esc_html_e( 'Choose an icon','wp-education' ); ?></p>
		</div>
	<?php
	}
}


/* Edit term page */ 

if( !function_exists('ep_taxonomy_edit_icon_field') ){
	function ep_taxonomy_edit_icon_field($term) {
	 
		// put the term ID into a variable
		$t_id = $term->term_id;
	 
		// retrieve the existing value(s) for this meta field. This returns an array
		$ep_term_meta = get_option( "taxonomy_$t_id" ); ?>
		<tr class="form-field">
		<th scope="row" valign="top"><label for="ep_term_meta[ep_cat_icons]"><?php esc_html_e( 'Icon', 'wp-education' ); ?></label></th>
			<td>
				<div class="ep-icon-picker-wrapper" data-pickerid="fa" data-iconsets='{"fa":"Category Icon"}'>
					<input type="text" name="ep_term_meta[ep_cat_icons]" id="ep-icon-picker" value="<?php echo esc_attr( $ep_term_meta['ep_cat_icons'] ) ? esc_attr( $ep_term_meta['ep_cat_icons'] ) : ''; ?>">
				</div>
				<p class="description"><?php esc_html_e( 'Choose an icon','wp-education' ); ?></p>
			</td>
		</tr>
	<?php
	}
}


/* Save extra taxonomy fields callback function */

if( !function_exists('ep_save_taxonomy_icon') ){
	function ep_save_taxonomy_icon( $term_id ) {
		if ( isset( $_POST['ep_term_meta'] ) ) {
			$t_id = $term_id;
			$ep_term_meta = get_option( "taxonomy_$t_id" );
			$cat_keys = array_keys( $_POST['ep_term_meta'] );
			foreach ( $cat_keys as $key ) {
				if ( isset ( $_POST['ep_term_meta'][$key] ) ) {
					$ep_term_meta[$key] = $_POST['ep_term_meta'][$key];
				}
			}
			// Save the option array.
			update_option( "taxonomy_$t_id", $ep_term_meta );
		}
	}
}


/**
 * add icon to texonomy column
 */

/* Column Head */
if( !function_exists('ep_columns_head') ){
	function ep_columns_head($defaults) {
	    $defaults['ep_cat_icons']  = esc_html__( 'Icon','wp-education' );
	    return $defaults;
	}
}


/* Column Content */
if( !function_exists('ep_columns_content_taxonomy') ){
	function ep_columns_content_taxonomy($c, $column_name, $term_id) {
	    if ($column_name == 'ep_cat_icons') {
	    	$ep_term_meta = get_option( "taxonomy_$term_id" );
	        echo '<i class="fa-2x '.$ep_term_meta['ep_cat_icons'].'"></i>';
	    }
	}
}




/**
 * Making Font Awesome icons string for icon picker 
 */

if( !function_exists('ep_font_awesome_icons_for_iconpicker') ){
	function ep_font_awesome_icons_for_iconpicker(){
		$pattern = '/\.(fa-(?:\w+(?:-)?)+):before\s+{\s*content:\s*"\\\\(.+)";\s+}/';
		$subject =  wp_remote_fopen( get_template_directory_uri().'/assets/css/font-awesome.css' );
		preg_match_all($pattern, $subject, $matches, PREG_SET_ORDER);

		foreach($matches as $match) {
		    $icons[$match[1]] = $match[2];
		}

		ksort($icons);

		$output = array();

		foreach ($icons as $key => $icon) {
			$output[] = 'fa '.$key;
		}

		return "'".implode( "','", $output )."'";
	}
}

/**
 * Making themify icons string for icon picker 
 */

if( !function_exists('ep_themify_icons_for_iconpicker') ){
	function ep_themify_icons_for_iconpicker(){


		$pattern = '/\.ti-(.*):/';
		$subject =  wp_remote_fopen( get_template_directory_uri().'/assets/css/themify-icons.css' );
		preg_match_all($pattern, $subject, $matches, PREG_SET_ORDER);


		if( !empty($matches) ){
			foreach($matches as $match) {
			   $icons[] = 'ti-' . $match[1];
			}
			
			ksort( $icons );

			return "'".implode( "','", $icons )."'";
		}
	}
}



/**
 * Making devicon icons string for icon picker 
 */


if( !function_exists('ep_devicon_icons_for_iconpicker') ){
	function ep_devicon_icons_for_iconpicker(){

		$icons_json = wp_remote_fopen( get_template_directory_uri().'/assets/json/devicon.json' );

		$icons_object = json_decode($icons_json);

		$icons_array = json_decode(json_encode($icons_object), True);

		$output = array();
		$icon_class = '';

		foreach ($icons_array as $icons) {

			foreach ( $icons['versions']['font'] as $icons_type ) {
				$icon_class = 'devicon-'.$icons['name'].'-'.$icons_type;
			}

			$output[] = $icon_class;
		}

		return "'".implode( "','", $output )."'";
	}
}



/**
 * Trigger the icon picker
 */

add_action( 'admin_footer', 'ep_course_category_icon_init' );

if( !function_exists('ep_course_category_icon_init') ){
	function ep_course_category_icon_init(){
		$screen = get_current_screen();
		if( $screen->id == 'edit-course_category' ){
			?>
			<script type="text/javascript">
			    jQuery(document).ready(function($) {
			    	var ep_course_icons = {
					    'Font Awesome' 	: [<?php echo ep_font_awesome_icons_for_iconpicker();?>],
					    'Themify Icons' : [<?php echo ep_themify_icons_for_iconpicker();?>],
					    'Devicon'		: [<?php echo ep_devicon_icons_for_iconpicker();?>],
					};

			        $('#ep-icon-picker').fontIconPicker({
			            source:    ep_course_icons,
			            emptyIcon: false,
			            hasSearch: true,
			            iconsPerPage: 48,
			        });
			    });
			</script>
			<?php
		}
	}
}