<?php

/**
 * WP Education Custom WooCommerce Functions
 *
 * Author: Xoo Themes
 * Since : 1.0
 */

/**
 * Adding WooCommerce 3.0 gallery and Zoom Support
 */

if(!function_exists('ep_wooCommerce_theme_setup')){
	function ep_wooCommerce_theme_setup() {
		$ep_need_woo_zoom = cs_get_option('ep_need_woo_zoom');
		$ep_need_woo_lightbox = cs_get_option('ep_need_woo_lightbox');
		$ep_need_woo_lightbox_slider = cs_get_option('ep_need_woo_lightbox_slider');

		if( $ep_need_woo_zoom == true ){
			add_theme_support( 'wc-product-gallery-zoom' );
		}
		if( $ep_need_woo_lightbox == true ){
			add_theme_support( 'wc-product-gallery-lightbox' );
		}
		if( $ep_need_woo_lightbox_slider == true ){
			add_theme_support( 'wc-product-gallery-slider' );
		}
	}
}

add_action( 'after_setup_theme', 'ep_wooCommerce_theme_setup' );

/**
 * Enqueue WooCommerce scripts and styles.
 */

if(!function_exists('ep_woocommerce_scripts')){
	function ep_woocommerce_scripts() {
		wp_enqueue_style( 'ep-woocommerce-main', get_template_directory_uri() . '/css/ep-woocommerce-main.css', array(), '1.0' );
	}
}
add_action( 'wp_enqueue_scripts', 'ep_woocommerce_scripts' );



/**
 * Check WooCommerce
 */

if ( ! function_exists( 'is_woocommerce_activated' ) ) {
	function is_woocommerce_activated() {
		if ( class_exists( 'woocommerce' ) ) { return true; } else { return false; }
	}
}


/**
 * Content area class
 */

add_filter( 'educationpress_content_area_class', 'educationpress_wocommerce_contet_area_class' );
if(!function_exists('educationpress_wocommerce_contet_area_class')){
	function educationpress_wocommerce_contet_area_class ( $class ) {

		if( is_shop() ){

			$ep_shop_layout = cs_get_option('ep_shop_layout');

			if( $ep_shop_layout == 'right' ){
				$class = 'col-md-9';
			}elseif ( $ep_shop_layout == 'left' ) {
				$class = 'col-md-9 col-md-push-3';
			}elseif( $ep_shop_layout = 'full_width' ){
				$class = 'col-md-12';
			}

		}

		return $class;
	}
}


/**
 * Widget area class
 */

add_filter( 'educationpress_widget_area_class', 'ep_woocomerce_widget_area_class' );
if(!function_exists('ep_woocomerce_widget_area_class')){
	function ep_woocomerce_widget_area_class ( $class ) {
		
		if( is_shop() ){

			$ep_shop_layout = cs_get_option('ep_shop_layout');

			if( $ep_shop_layout == 'right' ){
				$class = 'col-md-3';
			}elseif ( $ep_shop_layout == 'left' ) {
				$class = 'col-md-3 col-md-pull-9';
			}elseif( $ep_shop_layout = 'full_width' ){
				$class = '';
			}

		}
		
		return $class;

	}
}



/**
 * Register widget area.
 *
 * @link https://developer.wordpress.org/themes/functionality/sidebars/#registering-a-sidebar
 */

if(!function_exists('ep_woocommerce_widgets_init')){
	function ep_woocommerce_widgets_init() {
		register_sidebar( array(
			'name'          => esc_html__( 'WooCommerce Shop', 'wp-education' ),
			'id'            => 'woocommerce_shop',
			'description'   => esc_html__( 'Add widgets here. It will be shown to the WooCommerce shop and few other WooCommerce pages.', 'wp-education' ),
			'before_widget' => '<section id="%1$s" class="widget %2$s">',
			'after_widget'  => '</section>',
			'before_title'  => '<h3 class="widget-title">',
			'after_title'   => '</h3>',
		) );
		register_sidebar( array(
			'name'          => esc_html__( 'WooCommerce Product', 'wp-education' ),
			'id'            => 'woocommerce_product',
			'description'   => esc_html__( 'Add widgets here. It will be shown to the WooCommerce product page.', 'wp-education' ),
			'before_widget' => '<section id="%1$s" class="widget %2$s">',
			'after_widget'  => '</section>',
			'before_title'  => '<h3 class="widget-title">',
			'after_title'   => '</h3>',
		) );
	}
}

add_action( 'widgets_init', 'ep_woocommerce_widgets_init' );



/**
 * Woo Page Title
 */


add_filter( 'ep_theme_page_title', 'ep_woocommerce_page_title' );

if(!function_exists('ep_woocommerce_page_title')){
	function ep_woocommerce_page_title( $title ){
		if( is_shop() || is_singular( 'product' ) ){
			$title = woocommerce_page_title( false );
		}

		return $title;
	}
}


/**
 * Remove default Woo Page Title
 */

add_filter( 'woocommerce_show_page_title' , 'ep_woo_hide_page_title' );

if(!function_exists('ep_woo_hide_page_title')){
	function ep_woo_hide_page_title() {
		return false;
	}
}

/**
 * Shop product columns
 */

add_filter('loop_shop_columns', 'ep_woocommerce_product_loop_columns');

if (!function_exists('ep_woocommerce_product_loop_columns')) {
	function ep_woocommerce_product_loop_columns() {
		$ep_shop_loop_column = cs_get_option('ep_shop_loop_column');
		return $ep_shop_loop_column;
	}
}

/**
 * Adding column number to body class
 */

add_filter('body_class', 'ep_woocommerce_body_class');

if(!function_exists('ep_woocommerce_body_class')){
	function ep_woocommerce_body_class($classes) {
		$ep_shop_loop_column = cs_get_option('ep_shop_loop_column');

	    if ( is_woocommerce()) {
	        $classes[] = 'ep-product-columns-'.$ep_shop_loop_column;
	    }
	    return $classes;
	}
}

/**
 * Shop filter wrapper
 */

add_action( 'woocommerce_before_shop_loop', 'ep_woocommerce_shop_filter_wrapper_start', 10 );
add_action( 'woocommerce_before_shop_loop', 'ep_woocommerce_shop_filter_wrapper_end', 40 );

if(!function_exists('ep_woocommerce_shop_filter_wrapper_start')){
	function ep_woocommerce_shop_filter_wrapper_start(){
		echo '<div class="ep-woocommerce-shop-filter-wrapper clearfix">';
	}
}

if(!function_exists('ep_woocommerce_shop_filter_wrapper_end')){
	function ep_woocommerce_shop_filter_wrapper_end(){
		echo '</div>';
	}
}

/**
 * Shop loop item wrapper
 */

add_action( 'woocommerce_before_shop_loop_item_title', 'ep_woocommerce_shop_loop_wrapper_start', 20 );

if(!function_exists('ep_woocommerce_shop_loop_wrapper_start')){
	function ep_woocommerce_shop_loop_wrapper_start(){
		echo '<div class="ep-product-wrapper-inner">';
	}
}

add_action( 'woocommerce_after_shop_loop_item', 'ep_woocommerce_shop_loop_wrapper_end', 20 );

if(!function_exists('ep_woocommerce_shop_loop_wrapper_end')){
	function ep_woocommerce_shop_loop_wrapper_end(){
		echo '</div>';
	}
}

/**
 * Shop loop cart wrapper
 */

add_action( 'woocommerce_after_shop_loop_item', 'ep_woocommerce_shop_cart_wrapper_start', 5 );

if(!function_exists('ep_woocommerce_shop_cart_wrapper_start')){
	function ep_woocommerce_shop_cart_wrapper_start(){
		echo '<div class="ep-cart-wrapper">';
	}
}

add_action( 'woocommerce_after_shop_loop_item', 'ep_woocommerce_shop_cart_wrapper_end', 10 );

if(!function_exists('ep_woocommerce_shop_cart_wrapper_end')){
	function ep_woocommerce_shop_cart_wrapper_end(){
		echo '</div>';
	}
}

/**
 * Move the loop price
 */

remove_action( 'woocommerce_after_shop_loop_item_title', 'woocommerce_template_loop_price', 10 );
add_action( 'woocommerce_after_shop_loop_item', 'woocommerce_template_loop_price', 5 );

/**
 * Move the loop link close
 */

remove_action( 'woocommerce_after_shop_loop_item', 'woocommerce_template_loop_product_link_close', 5 );
add_action( 'woocommerce_before_shop_loop_item_title', 'woocommerce_template_loop_product_link_close', 15 );


add_action( 'woocommerce_before_shop_loop_item_title', 'woocommerce_template_loop_product_link_open', 25 );
add_action( 'woocommerce_after_shop_loop_item_title', 'woocommerce_template_loop_product_link_close', 10 );

/**
 * Related products
 */

add_filter( 'woocommerce_output_related_products_args', 'ep_woocommerce_related_products_args' );

if(!function_exists('ep_woocommerce_related_products_args')){
	function ep_woocommerce_related_products_args( $args ) {
		$args['posts_per_page'] = cs_get_option('ep_related_per_page');
		$args['columns'] = cs_get_option('ep_related_loop_column');

		return $args;
	}
}

/**
 * Single product wrapper
 */

add_action( 'woocommerce_before_single_product_summary', 'ep_woocommerce_single_product_wrapper_start', 5 );

if(!function_exists('ep_woocommerce_single_product_wrapper_start')){
	function ep_woocommerce_single_product_wrapper_start(){
		echo '<div class="ep-single-product-wrapper-inner clearfix">';
	}
}


add_action( 'woocommerce_after_single_product_summary', 'ep_woocommerce_single_product_wrapper_end', 5 );

if(!function_exists('ep_woocommerce_single_product_wrapper_end')){
	function ep_woocommerce_single_product_wrapper_end(){
		echo '</div>';
	}
}


/**
 * Number of products in shop page
 */

add_filter( 'loop_shop_per_page', 'ep_woocommerce_shop_number_of_products', 20 );

if(!function_exists('ep_woocommerce_shop_number_of_products')){
	function ep_woocommerce_shop_number_of_products( $number ){
		return cs_get_option('ep_shop_number_of_products');
	}
}
