<?php
/**
 * Custom template tags for this theme.
 *
 * Eventually, some of the functionality here could be replaced by core features.
 *
 * @package educationpress
 */


if ( ! function_exists( 'educationpress_posted_on' ) ) :
/**
 * Prints HTML with meta information for the current post-date/time and author.
 */
function educationpress_posted_on() {
	$time_string = '<time class="entry-date published updated" datetime="%1$s">%2$s</time>';
	if ( get_the_time( 'U' ) !== get_the_modified_time( 'U' ) ) {
		$time_string = '<time class="entry-date published" datetime="%1$s">%2$s</time><time class="updated" datetime="%3$s">%4$s</time>';
	}

	$time_string = sprintf( $time_string,
		esc_attr( get_the_date( 'c' ) ),
		esc_html( get_the_date() ),
		esc_attr( get_the_modified_date( 'c' ) ),
		esc_html( get_the_modified_date() )
	);

	echo '<span class="posted-on">' . $time_string . '</span>'; // WPCS: XSS OK.

}
endif;


if ( ! function_exists( 'get_educationpress_posted_on' ) ) :
/**
 * Return HTML with meta information for the current post-date/time and author.
 */	
function get_educationpress_posted_on() {
	ob_start();
		educationpress_posted_on();
	return ob_get_clean();
}
endif;


if ( ! function_exists( 'ep_wp_post_meta' ) ) :
/**
 * Prints HTML with meta information for the current post-date/time and author.
 */
function ep_wp_post_meta( $show_byline = true,  $show_time_string = true, $show_first_category = true, $show_tag = true, $show_print_comments = true ) {
	$print_comments = $first_category = $output = '';

	$time_string = '<span>' . get_educationpress_posted_on() . '</span>';

	$byline = sprintf(
		_x( '%s', 'post author',  'wp-education' ),
		'<span><a class="ep-post-author" href="' . esc_url( get_author_posts_url( get_the_author_meta( 'ID' ) ) ) . '">' . get_avatar( get_the_author_meta( 'ID' ), 34 ) . esc_html( get_the_author_meta('display_name') ) . '</a></span>'
	);

	$first_category = get_post_first_category( get_the_id(), 'category' );

	if( $first_category ){
		$first_category = '<span>'. $first_category .'</span>';
	}

	$tags = get_the_tag_list('',', ','');

	if( $tags ){
		$tags = '<span>'. $tags .'</span>';
	}

	$num_comments = get_comments_number();

	if ( comments_open() && ! post_password_required() ) {
		if ( $num_comments == 0 ) {
			$comments = esc_html__('Add a Comment', 'wp-education');
		} elseif ( $num_comments > 1 ) {
			$comments = $num_comments . esc_html__(' Comments', 'wp-education');
		} else {
			$comments = esc_html__('1 Comment', 'wp-education');
		}
		$print_comments = '<span><a href="' . esc_url( get_comments_link() ) .'">'. $comments.'</a></span>';
	}

	if( $show_byline == true ){
		$output .= $byline;
	}

	if( $show_time_string == true ){
		$output .= $time_string;
	}

	if( $show_first_category == true ){
		$output .= $first_category;
	}

	if( $show_tag == true ){
		$output .= $tags;
	}

	if( $show_print_comments == true ){
		$output .= $print_comments;
	}

	echo  $output;
}
endif;


if ( ! function_exists( 'educationpress_entry_footer' ) ) :
/**
 * Prints HTML with meta information for the read more link & post edit.
 */
function educationpress_entry_footer() {

	if ( 'post' === get_post_type() && !is_single() ) {

		$permalink = get_permalink();
		printf( '<a class="btn btn-primary btn-lg ep-btn-more" href="%1$s">' . esc_html( apply_filters( 'ep_post_read_more_text', esc_html__( 'Read More', 'wp-education' ) ) ) . '</a>', esc_url( $permalink ) );
	}

	edit_post_link(
		sprintf(
			/* translators: %s: Name of current post */
			esc_html__( 'Edit %s', 'wp-education' ),
			the_title( '<span class="screen-reader-text">"', '"</span>', false )
		),
		'<span class="edit-link pull-right">',
		'</span>'
	);
}
endif;

/**
 * Returns true if a blog has more than 1 category.
 *
 * @return bool
 */

if ( ! function_exists( 'educationpress_categorized_blog' ) ){
	function educationpress_categorized_blog() {
		if ( false === ( $all_the_cool_cats = get_transient( 'educationpress_categories' ) ) ) {
			// Create an array of all the categories that are attached to posts.
			$all_the_cool_cats = get_categories( array(
				'fields'     => 'ids',
				'hide_empty' => 1,
				// We only need to know if there is more than one category.
				'number'     => 2,
			) );

			// Count the number of categories that are attached to the posts.
			$all_the_cool_cats = count( $all_the_cool_cats );

			set_transient( 'educationpress_categories', $all_the_cool_cats );
		}

		if ( $all_the_cool_cats > 1 ) {
			// This blog has more than 1 category so educationpress_categorized_blog should return true.
			return true;
		} else {
			// This blog has only 1 category so educationpress_categorized_blog should return false.
			return false;
		}
	}
}

/**
 * Flush out the transients used in educationpress_categorized_blog.
 */

if ( ! function_exists( 'educationpress_category_transient_flusher' ) ){
	function educationpress_category_transient_flusher() {
		if ( defined( 'DOING_AUTOSAVE' ) && DOING_AUTOSAVE ) {
			return;
		}
		// Like, beat it. Dig?
		delete_transient( 'educationpress_categories' );
	}
}
add_action( 'edit_category', 'educationpress_category_transient_flusher' );
add_action( 'save_post',     'educationpress_category_transient_flusher' );
