<?php

/**
 * WP Education Theme Custom Functions
 * Author : XooThemes
 */


/**
 * Register Google fonts.
 *
 * @return string Google fonts URL for the theme.
 */


if ( ! function_exists( 'educationpress_theme_main_fonts_url' ) ) {

	function educationpress_theme_main_fonts_url() {
	    $fonts_url = '';
	    $fonts     = array();
	    $subsets   = '';

	    if ( 'off' !== esc_html_x( 'on', 'Montserrat font: on or off', 'wp-education' ) ) {
	        $fonts[] = 'Montserrat:400,600,700';
	    }

	    if ( $fonts ) {
	        $fonts_url = add_query_arg( array(
	            'family' => urlencode( implode( '|', $fonts ) ),
	            'subset' => urlencode( $subsets ),
	        ), 'https://fonts.googleapis.com/css' );
	    }

	    return $fonts_url;
	}
}


if ( ! function_exists( 'educationpress_testimonial_fonts_url' ) ) {

	function educationpress_testimonial_fonts_url() {
	    $fonts_url = '';
	    $fonts     = array();
	    $subsets   = '';

	    if ( 'off' !== esc_html_x( 'on', 'Droid Serif font: on or off', 'wp-education' ) ) {
	        $fonts[] = 'Droid Serif';
	    }

	    if ( $fonts ) {
	        $fonts_url = add_query_arg( array(
	            'family' => urlencode( implode( '|', $fonts ) ),
	            'subset' => urlencode( $subsets ),
	        ), 'https://fonts.googleapis.com/css' );
	    }

	    return $fonts_url;
	}
}


/**
 * Enqueue Google Fonts styles
 */

add_action( 'wp_enqueue_scripts', 'educationpress_prefix_scripts' );

if( !function_exists('educationpress_prefix_scripts') ){
	function educationpress_prefix_scripts() {

	    wp_enqueue_style( 'educationpress-main-fonts', educationpress_theme_main_fonts_url(), array(), null );
	    wp_register_style( 'educationpress-testimonial-fonts', educationpress_testimonial_fonts_url(), array(), null );

	}
}


/**
 * Check a plugin activate
 */

if( !function_exists('educationpress_plugin_active') ){
	function educationpress_plugin_active( $plugin ) {
		include_once( ABSPATH . 'wp-admin/includes/plugin.php' );
		if ( is_plugin_active( $plugin ) ) {
			return true;
		}

		return false;
	}
}

/**
 * Get CS Customize value with default value
 * 
 * $id : (string) (Required) customize feild id
 * 
 * $default_value : (string) (Optional) customize feild default falue
 */

if( !function_exists('educationpress_cs_get_customize_option') ){
	function educationpress_cs_get_customize_option ( $id, $default_value = null ){

		$value = cs_get_customize_option( $id );

		if( $value == null &&  $default_value != null ){
			$value = $default_value;
		}

        return $value;
	}
}

/**
 * Get CS Option value with default value
 * 
 * $id : (string) (Required) option feild id
 * 
 * $default_value : (string) (Optional) option feild default falue
 */

if( !function_exists('educationpress_cs_get_option') ){
	function educationpress_cs_get_option ( $id, $default_value = null ){

		$value = cs_get_option( $id );

		if( $value == null &&  $default_value != null ){
			$value = $default_value;
		}

        return $value;
	}
}


/**
 *  Course results progress
 */

remove_action( 'learn_press_after_profile_loop_course', 'learn_press_after_profile_tab_loop_course', 5, 2 );


/**
 * Single Course Page
 */

remove_action( 'learn_press_before_main_content', 'learn_press_breadcrumb' );
//add_action( 'ep_after_course_info', 'learn_press_course_students_list', 10 );


/**
 * Single Course Page [ Landing ]
 */

remove_action( 'learn_press_content_landing_summary', 'learn_press_course_thumbnail', 5 );
remove_action( 'learn_press_content_landing_summary', 'learn_press_course_title', 10 );
remove_action( 'learn_press_content_landing_summary', 'learn_press_course_meta_start_wrapper', 15 );
remove_action( 'learn_press_content_landing_summary', 'learn_press_course_price', 25 );
remove_action( 'learn_press_content_landing_summary', 'learn_press_course_students', 30 );
remove_action( 'learn_press_content_landing_summary', 'learn_press_course_meta_end_wrapper', 35 );
remove_action( 'learn_press_content_landing_summary', 'learn_press_course_enroll_button', 45 );
remove_action( 'learn_press_content_landing_summary', 'learn_press_course_tabs', 50 );
remove_action( 'learn_press_content_landing_summary', 'learn_press_course_progress', 60 );
remove_action( 'learn_press_content_landing_summary', 'learn_press_course_buttons', 70 );
remove_action( 'learn_press_content_landing_summary', 'learn_press_course_students_list', 75 );

add_action( 'learn_press_content_landing_summary', 'educationpress_before_course_header', 5 );
add_action( 'learn_press_content_landing_summary', 'learn_press_course_title', 10 );
add_action( 'learn_press_content_landing_summary', 'learn_press_course_meta_start_wrapper', 15 );
add_action( 'learn_press_content_landing_summary', 'educationpress_course_instructor', 20 );
add_action( 'learn_press_content_landing_summary', 'educationpress_course_category', 25 );
add_action( 'learn_press_content_landing_summary', 'educationpress_course_ratings', 30 );
add_action( 'learn_press_content_landing_summary', 'learn_press_course_progress', 35 );
add_action( 'learn_press_content_landing_summary', 'learn_press_course_meta_end_wrapper', 40 );
add_action( 'learn_press_content_landing_summary', 'educationpress_course_payment_landing', 45 );
add_action( 'learn_press_content_landing_summary', 'educationpress_after_course_header', 50 );
add_action( 'learn_press_content_landing_summary', 'learn_press_course_thumbnail', 55 );
add_action( 'learn_press_content_landing_summary', 'learn_press_course_tabs', 60 );
add_action( 'learn_press_content_landing_summary', 'educationpress_relative_courses', 60 );



/**
 * Single Course Page [ Learning ]
 */

remove_action( 'learn_press_content_learning_summary', 'learn_press_course_thumbnail', 5 );
remove_action( 'learn_press_content_learning_summary', 'learn_press_course_meta_start_wrapper', 10 );
remove_action( 'learn_press_content_learning_summary', 'learn_press_course_status', 15 );
remove_action( 'learn_press_content_learning_summary', 'learn_press_course_instructor', 20 );
remove_action( 'learn_press_content_learning_summary', 'learn_press_course_students', 25 );
remove_action( 'learn_press_content_learning_summary', 'learn_press_course_meta_end_wrapper', 30 );
remove_action( 'learn_press_content_learning_summary', 'learn_press_course_progress', 45 );
remove_action( 'learn_press_content_learning_summary', 'learn_press_course_tabs', 50 );
remove_action( 'learn_press_content_learning_summary', 'learn_press_course_buttons', 65 );
remove_action( 'learn_press_content_learning_summary', 'learn_press_course_students_list', 75 );

add_action( 'learn_press_content_learning_summary', 'educationpress_before_course_header', 5 );
add_action( 'learn_press_content_learning_summary', 'learn_press_course_title', 10 );
add_action( 'learn_press_content_learning_summary', 'learn_press_course_meta_start_wrapper', 15 );
add_action( 'learn_press_content_learning_summary', 'educationpress_course_instructor', 20 );
add_action( 'learn_press_content_learning_summary', 'educationpress_course_ratings', 30 );
add_action( 'learn_press_content_learning_summary', 'learn_press_course_progress', 35 );
add_action( 'learn_press_content_learning_summary', 'learn_press_course_meta_end_wrapper', 40 );
add_action( 'learn_press_content_learning_summary', 'educationpress_course_payment_learning', 45 );
add_action( 'learn_press_content_learning_summary', 'educationpress_after_course_header', 50 );
add_action( 'learn_press_content_learning_summary', 'learn_press_course_thumbnail', 60 );
add_action( 'learn_press_content_learning_summary', 'learn_press_course_tabs', 65 );




/**
 * archive courses page
 */

add_action( 'learn_press_after_courses_loop_item', 'educationpress_learn_press_courses_loop_item_short_description', 10 );
add_action( 'learn_press_before_courses_loop_item', 'educationpress_learn_press_before_course_item_figure', 5 );
add_action( 'learn_press_before_courses_loop_item', 'educationpress_learn_press_before_course_item_thumbnail', 10 );
add_action( 'learn_press_before_courses_loop_item', 'learn_press_courses_loop_item_thumbnail', 15 );
add_action( 'learn_press_before_courses_loop_item', 'educationpress_learn_press_wishlist', 20 );
add_action( 'learn_press_before_courses_loop_item', 'educationpress_learn_press_after_course_item_thumbnail', 25 );
add_action( 'learn_press_before_courses_loop_item', 'educationpress_learn_press_courses_loop_item_figcaption', 35 );

add_action( 'learn_press_after_courses_loop_item', 'ep_course_author', 13 );
if( cs_get_option( 'show_course_enroll_btn_n_price' ) == true ){
	add_action( 'learn_press_after_courses_loop_item', 'ep_course_students_enrolle_button', 14 );
}
if( cs_get_option( 'show_course_meta' ) == true ){
	add_action( 'learn_press_after_courses_loop_item', 'ep_learn_press_courses_loop_item_before_meta', 15 );
	if( cs_get_option( 'show_course_students' ) == true ){
		add_action( 'learn_press_after_courses_loop_item', 'ep_course_enrolled_students', 17 );
	}
	if( cs_get_option( 'show_course_review' ) == true ){
		add_action( 'learn_press_after_courses_loop_item', 'educationpress_course_ratings', 18 );
	}
	add_action( 'learn_press_after_courses_loop_item', 'educationpress_learn_press_courses_loop_item_after_meta', 32 );
}
add_action( 'learn_press_after_courses_loop_item', 'educationpress_learn_press_courses_loop_item_figcaption_end', 45 );
add_action( 'learn_press_after_courses_loop_item', 'educationpress_learn_press_after_course_item_figure', 50 );


remove_action( 'learn_press_courses_loop_item_title', 'learn_press_courses_loop_item_thumbnail', 10 );
remove_action( 'learn_press_after_courses_loop_item', 'learn_press_courses_loop_item_price', 25 );
remove_action( 'learn_press_after_courses_loop_item', 'learn_press_courses_loop_item_students', 20 );
remove_action( 'learn_press_after_courses_loop_item', 'learn_press_courses_loop_item_instructor', 15 );
remove_action( 'learn_press_after_courses_loop_item', 'learn_press_courses_loop_item_introduce', 30 );
remove_action( 'learn_press_before_main_content', 'learn_press_search_form' );


/**
 * Profile Page
 */

add_action( 'learn_press_user_profile_summary', 'educationpress_learn_press_before_user_profile_tabs', 8 );
add_action( 'learn_press_user_profile_summary', 'educationpress_learn_press_after_user_profile_tabs', 20 );



/**
 * Remove default Course wishlist button
 */

if ( educationpress_plugin_active( 'learnpress-wishlist/learnpress-wishlist.php' ) ) {
	$addon_wishlist = LP_Addon_Wishlist::instance();
	remove_action( 'learn_press_content_learning_summary', array( $addon_wishlist, 'wishlist_button' ), 100 );
}

/**
 * LP collections
 */

remove_action( 'learn_press_collections_before_single_summary', 'learn_press_collections_title', 5 );

add_filter( 'learn_press_collections_show_page_title', '__return_false' );


/**
 * Remove default course pre requirements notice
 */

if ( educationpress_plugin_active( 'learnpress-prerequisites-courses/learnpress-prerequisites-courses.php' ) && class_exists( 'LP_Addon_Prerequisites' ) ) {
	$addon_review = LP_Addon_Prerequisites::instance();
	remove_action( 'learn_press_content_landing_summary', array( $addon_review, 'enroll_notice' ), 34 );
	add_action( 'learn_press_content_landing_summary', array( $addon_review, 'enroll_notice' ), 4 );
}


/**
 * Pre Header
 */

add_action( 'ep_pre_header_bar', 'ep_pre_header_bar' );

if(!function_exists('ep_pre_header_bar')):
	function ep_pre_header_bar(){
		$ep_need_pre_header = cs_get_option( 'ep_need_pre_header' );
		$ep_need_pre_header_mobile = cs_get_option( 'ep_need_pre_header_mobile' );
		$ep_pre_header_text = educationpress_cs_get_option( 'ep_pre_header_text' );
		$ep_pre_header_phone = educationpress_cs_get_option( 'ep_pre_header_phone' );
		$ep_pre_header_email = educationpress_cs_get_option( 'ep_pre_header_email' );
		$ep_pre_header_email = sanitize_email( $ep_pre_header_email );
		$ep_pre_header_right_content = educationpress_cs_get_option( 'ep_pre_header_right_content', 'social' );
		$ep_pre_header_right_menu = educationpress_cs_get_option( 'ep_pre_header_right_menu', '' );
		$ep_pre_header_right_text = educationpress_cs_get_option( 'ep_pre_header_right_text', '' );
		$ep_pre_header_right_social_icons = educationpress_cs_get_option( 'ep_pre_header_right_social_icons', '' );
		if( $ep_need_pre_header ):
			?>
			<div class="ep-pre-header<?php echo esc_attr( $ep_need_pre_header_mobile == true ? ' ep-pre-header-mobile-disable' : '' ); ?>">
				<div class="container">
					<div class="row">
						<?php if( $ep_pre_header_text || $ep_pre_header_phone || $ep_pre_header_email ):?>
							<div class="col-lg-6 col-md-8 ep-pre-header-item-left">
								<?php 
									if( $ep_pre_header_text ){
										printf( '<span>%s</span>', esc_html($ep_pre_header_text, 'wp-education') );
									}
								?>
								<?php 
									if( $ep_pre_header_phone ){
										printf( '<span class="ep-top-bar-mobile"><i class="fa fa-phone"></i><a href="%s">%s</a></span>', 'tel:' . esc_attr( $ep_pre_header_phone ), esc_html( $ep_pre_header_phone, 'wp-education' ) );
									}
								?>
								<?php 
									if( $ep_pre_header_email ){
										printf( '<span class="ep-top-bar-email"><i class="fa fa-envelope"></i><a href="%s">%s</a></span>', 'mailto:' . antispambot( $ep_pre_header_email, 1 ), antispambot( $ep_pre_header_email ) );
									}
								?>
							</div>
						<?php endif;?>
						<div class="col-lg-6 col-md-4 ep-pre-header-item-right text-right">
							<?php 
								switch ($ep_pre_header_right_content) {
									case 'menu':
										?>
											<div class="ep-pre-header-menu">
												<?php
													wp_nav_menu( array(
													    'menu'              => $ep_pre_header_right_menu,
													    'depth'             => 1,
													    'container'         => '',
													    'fallback_cb'		=> false
													));
												?>
											</div>
										<?php
										break;
									
									case 'text':
										printf( '<span class="ep-pre-header-right-text">%s</span>', esc_html( $ep_pre_header_right_text, 'wp-education') );
										break;

									case 'social':
										?>
										<ul class="ep-pre-header-right-social">
											<?php 
												foreach ($ep_pre_header_right_social_icons as $icon) {
													printf( '<li><a href="%s"><i class="%s"></i></a></li>', esc_url( $icon['url'] ), esc_attr( $icon['icon'] ) );
												}
											?>
										</ul>
										<?php
										break;	
								}
							?>
						</div>
					</div>
				</div>
			</div>
			<?php
		endif;
	}
endif;


/**
 * Before Content
 */

add_action( 'educationpress_before_content', 'educationpress_before_main_content' );

if( !function_exists('educationpress_before_main_content') ){
	function educationpress_before_main_content(){
		$x_class = $course_layout = $course_category = '';
		$course_category = false;

		if( is_post_type_archive('lp_course') ){
			$course_layout = cs_get_option('course_layout');
		}

		if( is_tax('course_category') && $course_layout != 'full_width' ){
			$course_category = true;
		}

		if( ep_is_blog() == true || is_singular( 'lp_course' ) || is_post_type_archive( 'lp_course' ) || $course_layout == 'right' || $course_layout == 'left' || $course_category == true || is_post_type_archive() == true || is_singular() == true ){
			$x_class = ' row';
		}

		if( is_singular('page') ){
			$x_class = '';
		}

		if( is_singular('lp_collection') ){
			$x_class = '';
		}
		?>
			<div class="educationpress-main-content-inner<?php echo esc_attr( apply_filters( 'educationpress_main_content_inner', $x_class ) ); ?>">
		<?php
	}
}


/**
 * After Content
 */

add_action( 'educationpress_after_content', 'educationpress_after_main_content' );

if( !function_exists('educationpress_after_main_content') ){
	function educationpress_after_main_content(){
		?>
			</div>
		<?php
	}
}



/**
 * is Blog
 */

if(!function_exists('ep_is_blog')){
	function ep_is_blog () {
		global  $post;
		$posttype = get_post_type($post );
		return ( ((is_archive()) || (is_author()) || (is_category()) || (is_home()) || (is_single()) || (is_tag())) && ( $posttype == 'post')  ) ? true : false ;
	}
}


/**
 * Content area class
 */

add_filter( 'educationpress_content_area_class', 'educationpress_contet_area_class' );

if(!function_exists('educationpress_contet_area_class')){
	function educationpress_contet_area_class ( $class ) {

		if( ep_is_blog() ){

			$blog_layout = cs_get_option('blog_layout');

			if( $blog_layout == 'right' ){
				$class = 'col-md-9';
			}elseif ( $blog_layout == 'left' ) {
				$class = 'col-md-9 col-md-push-3';
			}elseif( $blog_layout = 'full_width' ){
				$class = 'col-md-12';
			}

		}

		if( is_post_type_archive('lp_course') || is_tax('course_category') ){

			$course_layout = cs_get_option('course_layout');

			if( $course_layout == 'right' ){
				$class = 'col-md-9';
			}elseif ( $course_layout == 'left' ) {
				$class = 'col-md-9 col-md-push-3';
			}elseif( $course_layout = 'full_width' ){
				$class = 'col-md-12';
			}
		}

		if( is_singular( 'lp_course' ) ){
			
			$single_course_layout = cs_get_option('single_course_layout');

			if( $single_course_layout == 'right' ){
				$class = 'col-md-9';
			}elseif ( $single_course_layout == 'left' ) {
				$class = 'col-md-9 col-md-push-3';
			}elseif( $single_course_layout = 'full_width' ){
				$class = 'col-md-12';
			}
		}

		if( is_page() ){

			$page_sidebar_position = ep_get_post_meta( '_ep_page_side_options', 'page_sidebar_position', 'no_sidebar', true );

			if( $page_sidebar_position == 'right' ){
				$class = 'col-md-9';
			}elseif ( $page_sidebar_position == 'left' ) {
				$class = 'col-md-9 col-md-push-3';
			}elseif( $page_sidebar_position = 'no_sidebar' ){
				$class = 'page_no_sidebar';
			}

		}

		return $class;
	}
}

/**
 * Widget area class
 */

add_filter( 'educationpress_widget_area_class', 'educationpress_widget_area_class' );
if(!function_exists('educationpress_widget_area_class')){
	function educationpress_widget_area_class ( $class ) {
		
		if( ep_is_blog() ){

			$blog_layout = cs_get_option('blog_layout');

			if( $blog_layout == 'right' ){
				$class = 'col-md-3';
			}elseif ( $blog_layout == 'left' ) {
				$class = 'col-md-3 col-md-pull-9';
			}elseif( $blog_layout = 'full_width' ){
				$class = '';
			}

		}

		if( is_post_type_archive('lp_course') || is_tax('course_category') ){
			
			$course_layout = cs_get_option('course_layout');

			if( $course_layout == 'right' ){
				$class = 'col-md-3';
			}elseif ( $course_layout == 'left' ) {
				$class = 'col-md-3 col-md-pull-9';
			}elseif( $course_layout = 'full_width' ){
				$class = '';
			}
		}

		if( is_singular( 'lp_course' ) ){
			
			$single_course_layout = cs_get_option('single_course_layout');

			if( $single_course_layout == 'right' ){
				$class = 'col-md-3';
			}elseif ( $single_course_layout == 'left' ) {
				$class = 'col-md-3 col-md-pull-9';
			}elseif( $single_course_layout = 'full_width' ){
				$class = '';
			}
		}


		if( is_page() ){
			$page_sidebar_position = ep_get_post_meta( '_ep_page_side_options', 'page_sidebar_position', 'no_sidebar', true );

			if( $page_sidebar_position == 'right' ){
				$class = 'col-md-3';
			}elseif ( $page_sidebar_position == 'left' ) {
				$class = 'col-md-3 col-md-pull-9';
			}elseif( $page_sidebar_position = 'no_sidebar' ){
				$class = '';
			}
		}
		
		return $class;

	}
}


/**
 *  page footer wrapper class
 *  action located at content-page.php
 */

add_action( 'ep_page_footer_wrapper_class', 'ep_page_footer_wrapper_class_setup' );
if(!function_exists('ep_page_footer_wrapper_class_setup')){
	function ep_page_footer_wrapper_class_setup(){
		if ( is_page() ){
			$page_layout = ep_get_post_meta( '_ep_page_side_options', 'page_layout', 'grid', true );

			if( $page_layout && $page_layout == 'grid' ){
				$class = '';
			}else {
				$class = ' container';
			}
		}
		echo $class;
	}
}


/**
 * Logo Setup
 */

add_action( 'educationpress_logo_setup','educationpress_logo_setup_function' );

if( !function_exists('educationpress_logo_setup_function') ){
    function educationpress_logo_setup_function(){
    	$header_transparent = '';
    	$header_type = educationpress_cs_get_option( 'header_type', 'default' );
    	if( is_page() ){
    		$header_transparent = ep_get_post_meta( '_ep_page_side_options', 'header_transparent', '', true );
    	}
    	$ep_transparent_header_logo = educationpress_cs_get_option( 'ep_transparent_header_logo', '' );
    	?>
        <div class="logo-wrapper" itemscope itemtype="http://schema.org/Brand">
            <?php 
            	if( $header_type == 'transparent' || $header_transparent == true ){
            		if( $ep_transparent_header_logo != '' ){
            			echo ep_get_custom_logo($ep_transparent_header_logo);
            		}else {
            			printf( '<h1 class="site-title site-title-transparent"><a href="%s" rel="home">%s</a></h1>', esc_url( home_url( '/' ) ), esc_html( get_bloginfo( 'name' ) ) );
            		}
            	}elseif ( function_exists( 'the_custom_logo' ) && has_custom_logo() ) {
                    the_custom_logo();
                }else{
                    printf( '<h1 class="site-title"><a href="%s" rel="home">%s</a></h1>', esc_url( home_url( '/' ) ), esc_html( get_bloginfo( 'name' ) ) );
                }
            ?> 
        </div>
        <?php
    }
}


/**
 * EP Get Custom logo by attachment id
 */

if(!function_exists('ep_get_custom_logo')){
	function ep_get_custom_logo( $attachment_id = 0 ) {
	    $html = '';
	 
	    if ( $attachment_id ) {
	        $html = sprintf( '<a href="%1$s" class="custom-logo-link" rel="home">%2$s</a>',
	            esc_url( home_url( '/' ) ),
	            wp_get_attachment_image( $attachment_id, 'full', false, array(
	                'class'    => 'ep-custom-logo',
	                'itemprop' => 'logo',
	            ) )
	        );
	    }

	    return $html;
	}
}


/**
 * Get Social icons for instructors
 */

if(!function_exists('ep_get_instructor_social_icons')){
	function ep_get_instructor_social_icons( $user_id, $size = 'medium' ){
		if( !$user_id ){
			$user_id = get_current_user_id();
		}

		$twitter 	= get_the_author_meta( 'twitter', $user_id );
		$facebook 	= get_the_author_meta( 'facebook', $user_id );
		$gplus 		= get_the_author_meta( 'gplus', $user_id );
		$linkedin 	= get_the_author_meta( 'linkedin', $user_id );
		$youtube 	= get_the_author_meta( 'youtube', $user_id );

		if( $twitter || $facebook || $gplus || $linkedin || $youtube ):
			?>
				<div class="ep-user-social-wrapper ep-social-icons ep-social-icons-<?php echo $size; ?>">
					<ul class="ep-user-social">
						<?php 
							if( $facebook ){
								printf( '<li><a href="%s" class="course-author-social-facebook"><i class="fa fa-facebook"></i></a></li>', esc_url( $facebook ) );
							}
							if( $twitter ){
								printf( '<li><a href="%s" class="course-author-social-facebook"><i class="fa fa-twitter"></i></a></li>', esc_url( $twitter ) );
							}
							if( $gplus ){
								printf( '<li><a href="%s" class="course-author-social-facebook"><i class="fa fa-google-plus"></i></a></li>', esc_url( $gplus ) );
							}
							if( $linkedin ){
								printf( '<li><a href="%s" class="course-author-social-facebook"><i class="fa fa-linkedin"></i></a></li>', esc_url( $linkedin ) );
							}
							if( $youtube ){
								printf( '<li><a href="%s" class="course-author-social-facebook"><i class="fa fa-youtube"></i></a></li>', esc_url( $youtube ) );
							}
						?>
					</ul>
				</div>
			<?php
		endif;
	}
}



/**
 * Get Sidebars for CS framework
 */

if( !function_exists('ep_sidebars_list_on_option') ){
	function ep_sidebars_list_on_option(){
		$result = array();

        foreach( $GLOBALS['wp_registered_sidebars'] as $sidebar ) {
            $result[ esc_attr( $sidebar['id'] ) ] = esc_html( $sidebar['name'] );      
        }
        
        unset($result['footer-widgets']);

        return $result;
	}
}





/**
 * Get CS Meta value
 * 
 * $meta_section : (string) (Required) metabox section key
 * 
 * $meta_field : (string) (Required) metabox field key
 * 
 * $default_value : (string) (Optional) metabox default falue
 * 
 * $single : (bool) (Optional) Whether to return a single value. Default value: true

 * $id : int (Optional) Loop post id. Default value: null
 */

if( !function_exists('ep_get_post_meta') ){
	function ep_get_post_meta ( $meta_section, $meta_field, $default_value = null, $single = true, $id = null  ){

		if( !is_search() && !is_404() ){
			if( $id ){
				$values = get_post_meta( $id, $meta_section, true );
			}else{
				global $wp_query;
				$id = $wp_query->post->ID;
				$values = get_post_meta( $id, $meta_section, true );
				wp_reset_query();
			}

			$value = $default_value;

			if( isset($values) && is_array($values) ){
				if ( array_key_exists( $meta_field, $values ) ) {
		            $value = $values[$meta_field];
		        }
			}
		}else{
			$value = $default_value;
		}	

        return $value;
	}
}



/**
 * Page Layout setup
 */

add_filter( 'educationpress_container_class', 'educationpress_page_layout_setup' );

if( !function_exists('educationpress_page_layout_setup') ){
	function educationpress_page_layout_setup( $class ){
		if ( is_page() ){
			$page_layout = ep_get_post_meta( '_ep_page_side_options', 'page_layout', 'grid', true );

            if( $page_layout && $page_layout == 'grid' ){
            	$class = 'container';
            }else {
            	$class = 'fullwidth_page';
            }
		}

		if( is_post_type_archive( 'lp_course' ) ){
			$course_page_layout = cs_get_option( 'course_page_layout' );

			if( $course_page_layout && $course_page_layout == 'grid' ){
            	$class = 'container';
            }else {
            	$class = 'fullwidth_page container-fluid';
            }
		}

		return $class;
	}
}


/**
 * Page main content inner class
 */

add_filter( 'educationpress_main_content_inner', 'educationpress_page_main_content_inner_class' );

if( !function_exists('educationpress_page_main_content_inner_class') ){
	function educationpress_page_main_content_inner_class( $class ){
		if ( is_page() ){
			$page_sidebar_position = ep_get_post_meta( '_ep_page_side_options', 'page_sidebar_position', 'no_sidebar', true );

			if( $page_sidebar_position != 'no_sidebar' ){
				$class = ' row';
			}
		}
		return $class;
	}
}


/**
 * Theme main header
 */

add_action( 'ep_theme_main_header', 'ep_theme_main_header_setup' );

if( !function_exists('ep_theme_main_header_setup') ){
	function ep_theme_main_header_setup(){
		$header_transparent = '';
		if( is_page() ){
			$header_transparent = ep_get_post_meta( '_ep_page_side_options', 'header_transparent', '', true );
		}
		$header_type = educationpress_cs_get_option( 'header_type', 'default' );
		$ep_menu_hover_border = cs_get_option( 'ep_menu_hover_border' );
		$classes = array();

		if( $header_transparent && is_page() ){
			$classes[] = 'header-transparent';
		}elseif( $header_type == 'transparent' ){
			$classes[] = 'header-transparent';
			$classes[] = 'global-header-transparent';
		}

		if( $ep_menu_hover_border == true ){
			$classes[] = 'ep-menu-hover-border';
		}

		$classes = array_unique($classes);
		$classes = implode (" ", $classes);

		?>
		<header id="masthead" class="site-header-type-default site-header navbar navbar-default navbar-educationpress<?php echo esc_attr( $classes ? ' '.$classes : '' ); ?>">
			<?php do_action( 'ep_pre_header_bar' ); ?>
			<div class="site-header-wrapper">
				<div class="<?php echo esc_attr( apply_filters( 'educationpress_site_header_container_class', 'container' ) ); ?>">
					<div class="site-header-inner clearfix">
						<div class="site-branding navbar-header">
							<?php do_action( 'educationpress_logo_setup' ); ?>
						</div><!-- .site-branding -->

						<div class="ep-main-menu-wrapper">
							<?php 
								wp_nav_menu( array(
							        'menu'              => 'primary',
							        'theme_location'    => 'primary',
							        'depth'             => 4,
							        'container'         => 'div',
							        'container_class'   => 'collapse navbar-collapse',
							        'container_id'      => 'ep-site-navigation',
							        'menu_class'        => 'nav navbar-nav navbar-right ep-main-menu ep-megamenu',
							        'fallback_cb'       => 'wp_bootstrap_navwalker::fallback',
							        'walker'            => new wp_bootstrap_navwalker())
							    );
							?>
						</div>

						<div class="ep-mobile-menu-wrapper">
							<?php
								wp_nav_menu( array( 
									'theme_location'    => 'primary', 
									'menu_id'           => 'primary-menu',
									'depth'             => 4,
									'container'         => false,
									'menu_class'        => 'ep-mobile-menu',
								));
							?>
						</div>

					</div>
				</div>
			</div>
		</header><!-- #masthead -->
		<?php
	}
}



/**
 * Page Title
 */

add_action( 'ep_after_header', 'educationpress_page_title' );

if( !function_exists('educationpress_page_title') ){
	function educationpress_page_title(){

		$title = get_the_title();

		if( is_search() ){
			$title = esc_html__( 'Search result', 'wp-education' );
		}elseif( is_singular( 'lp_course' ) ){
			$terms = get_the_terms( get_the_id(), 'course_category' );
			if( $terms && !empty($terms) ){
				$term = array_shift($terms);
				$title = $term->name;
			}else{
				$title = esc_html__( 'Course','wp-education' );
			}
		}elseif( is_archive() ){
			$title = get_the_archive_title();
		}

		if( is_page() ){
			$need_page_title = ep_get_post_meta( '_ep_page_side_options', 'need_page_title', true, true );
		}else{
			$need_page_title = false;
		}

		if( is_home() ){
			$title = apply_filters( 'ep_blog_page_title', esc_html__( 'Blog','wp-education' ) );
		}

		if( is_404() ){
			$title = apply_filters( 'ep_not_found_page_title', esc_html__( '404','wp-education' ) );
		}

		$title = apply_filters( 'ep_theme_page_title', $title );

		$ep_show_breadcrumb = cs_get_option( 'ep_show_breadcrumb' );
		

		if( is_page() && $need_page_title != false || is_singular( 'lp_course' ) || is_singular( 'lp_collection' ) || is_singular( 'tribe_events' ) || is_singular( 'product' ) || is_archive() || is_home() || is_search() || is_404() ){
			?>
				<div class="educationpress-page-title-area">
					<div class="educationpress-page-title">
						<div class="container">
							<h1 class="entry-title"><?php echo esc_html( $title ); ?></h1>
						</div>
					</div>
					<?php if( $ep_show_breadcrumb == true ): ?>
						<div class="educationpress-breadcrumb-wrapper">
							<div class="container">
								<?php do_action( 'educationpress_breadcrumb' );?>
							</div>
						</div>
					<?php endif; ?>
				</div>
			<?php
		}

	}
}



/**
 * Setup breadcrumb
 */

add_action( 'educationpress_breadcrumb', 'educationpress_breadcrumb_setup', 10 );

if( !function_exists('educationpress_breadcrumb_setup') ){
	function educationpress_breadcrumb_setup( $args = array() ){

		if( function_exists('breadcrumb_trail') ){
			$args = wp_parse_args( $args, apply_filters( 'educationpress_breadcrumb_defaults', array() ) );
			breadcrumb_trail($args);
		}

	}
}

/**
 * Breadcrumb $args
 */

add_filter( 'educationpress_breadcrumb_defaults', 'educationpress_breadcrumb_args' );

if( !function_exists('educationpress_breadcrumb_args') ){
	function educationpress_breadcrumb_args( $args = array() ){

		$args = array(
		        'container'       => 'nav',
		        'before'          => '<div class="educationpress-breadcrumb">',
		        'after'           => '</div>',
		        'show_on_front'   => true,
		        'network'         => false,
		        'show_title'      => true,
		        'show_browse'     => false,
		        'echo'            => true,

		        'post_taxonomy' => array(
		            'post'  			=> 'post_tag',
		            'post'  			=> 'category',
		            'download'  		=> 'download_category',
		            'download'  		=> 'download_tag',
		            'download'  		=> 'course_category',
		            'download'  		=> 'course_tag',
		            'wpb_fp_portfolio'  => 'wpb_fp_portfolio_cat',
		            'tribe_events'  	=> 'tribe_events_cat',
		        ),

		        'labels' => array(
		            'browse'              => '',
		            'aria_label'          => esc_attr_x( 'Breadcrumbs', 'breadcrumbs aria label', 'wp-education' ),
		            'home'                => esc_html__( 'Home',                                  'wp-education' ),
		            'error_404'           => esc_html__( '404 Not Found',                         'wp-education' ),
		            'archives'            => esc_html__( 'Archives',                              'wp-education' ),
		            'search'              => esc_html__( 'Search results for &#8220;%s&#8221;',   'wp-education' ),
		            'paged'               => esc_html__( 'Page %s',                               'wp-education' ),
		            'archive_minute'      => esc_html__( 'Minute %s',                             'wp-education' ),
		            'archive_week'        => esc_html__( 'Week %s',                               'wp-education' ),
		            'archive_minute_hour' => '%s',
		            'archive_hour'        => '%s',
		            'archive_day'         => '%s',
		            'archive_month'       => '%s',
		            'archive_year'        => '%s',
		        )
		);

		return $args;
	}
}


/**
 * Get Users ( course-instructors ) meta options
 */

if( !function_exists('educationpress_get_course_instructor') ){
	function educationpress_get_course_instructor(){

		$instructors = array();
		$users = get_users( array( 'role__in' => array( 'lp_teacher', 'administrator' ) ) );
		
		foreach ( $users as $user ) {
			$instructors[$user->ID] = $user->display_name;
		}

		return $instructors;
	}
}


/**
 * course author profile link
 */

if( !function_exists('educationpress_author_profile_url') ){
	function educationpress_author_profile_url( $author_id ){
		$output = '';
		$output .= home_url( '/' );

		$learn_press_profile_page_id = get_option( 'learn_press_profile_page_id' );
		$profile_page = get_post($learn_press_profile_page_id); 
		$profile_page_slug = $profile_page->post_name;
		if($profile_page_slug ){
			$output .= $profile_page_slug.'/';
		}

		$author_url = get_the_author_meta( 'user_login', $author_id);
		if($author_url){
			$output .= $author_url.'/';
		}

		return $output;
	}
}


/**
 * LP Purchase button text
 */

add_filter( 'learn_press_purchase_button_text', 'educationpress_purchase_button_text' );
if( !function_exists('educationpress_purchase_button_text') ){
	function educationpress_purchase_button_text( $text ){
		$text = educationpress_cs_get_option( 'purchase_button_text', esc_html__( 'Join', 'wp-education' ) );
		return $text;
	}
}


/**
 * LP Enroll button text
 */

add_filter( 'learn_press_enroll_button_text', 'educationpress_enroll_button_text' );
if( !function_exists('educationpress_enroll_button_text') ){
	function educationpress_enroll_button_text( $text ){
		$text = educationpress_cs_get_option( 'enroll_button_text', esc_html__( 'Enroll', 'wp-education' ) );
		return $text;
	}
}


/**
 * Course Payment landing
 */

if(!function_exists('educationpress_course_payment_landing')){
	function educationpress_course_payment_landing(){
		?>
		<div class="course-payment pull-right">
			<?php learn_press_course_price(); ?>
			<?php learn_press_course_buttons(); ?>
		</div>
		<?php
	}
}

/**
 * Course Payment learning
 */

if(!function_exists('educationpress_course_payment_learning')){
	function educationpress_course_payment_learning(){
		?>
		<div class="course-payment pull-right">
			<?php learn_press_course_buttons(); ?>
		</div>
		<?php
	}
}


/**
 * Before Course Header
 */

if(!function_exists('educationpress_before_course_header')){
	function educationpress_before_course_header(){
		?>
			<div class="ep-single-course-header clearfix">
		<?php
	}
}

/**
 * After Course Header
 */

if(!function_exists('educationpress_after_course_header')){
	function educationpress_after_course_header(){
		?>
			</div>
		<?php
	}
}


/**
 * Course instructor
 */

if(!function_exists('educationpress_course_instructor')){
	function educationpress_course_instructor(){
		?>
			<div class="course-author" itemscope="" itemtype="http://schema.org/Person">
				<?php printf( get_avatar( get_the_author_meta( 'ID' ), 40 ) ); ?>	
				<div class="author-contain">
					<label itemprop="jobTitle"><?php esc_html_e( 'Teacher', 'wp-education' ); ?></label>
					<div class="value" itemprop="name">
						<a href="<?php echo esc_url( educationpress_author_profile_url( get_the_author_meta('ID') ) ); ?>"><?php esc_html( the_author() ); ?></a>
					</div>
				</div>
			</div>
		<?php
	}
}



/**
 * Course instructor for course tab content
 */

if(!function_exists('ep_course_instructor_tab_content')){
	function ep_course_instructor_tab_content(){
		global $post;
		$instructors[] = $post->post_author;
		
		foreach ( $instructors as $instructor ) {

			$twitter 	= get_the_author_meta( 'twitter', $instructor );
			$facebook 	= get_the_author_meta( 'facebook', $instructor );
			$gplus 		= get_the_author_meta( 'gplus', $instructor );
			$linkedin 	= get_the_author_meta( 'linkedin', $instructor );
			$youtube 	= get_the_author_meta( 'youtube', $instructor );
			?>
			<div class="ep-course-instructor">
				<div class="ep-user-details">
					<div class="ep-user-avatar">
						<?php printf( get_avatar( $instructor, 110 ) ); ?>	
					</div>
					<div class="ep-user-name-wrapper">
						<a href="<?php echo esc_url( educationpress_author_profile_url( $instructor ) ); ?>"><h4 class="ep-user-display-name"><?php echo esc_html( get_the_author_meta( 'display_name', $instructor ) ); ?></h4></a>
						<?php if( $job = get_the_author_meta( 'job', $instructor ) ):?>
							<p class="ep-user-job"><?php echo esc_html($job); ?></p>
						<?php endif;?>
						<?php if( $twitter || $facebook || $gplus || $linkedin || $youtube ):?>
							<div class="ep-social-icons ep-social-icons-small">
								<ul class="ep-instructor-social">
									<?php 
										if( $facebook ){
											printf( '<li><a href="%s"><i class="fa fa-facebook"></i></a></li>', esc_url( $facebook ) );
										}
									?>
									<?php 
										if( $twitter ){
											printf( '<li><a href="%s"><i class="fa fa-twitter"></i></a></li>', esc_url( $twitter ) );
										}
									?>
									<?php 
										if( $gplus ){
											printf( '<li><a href="%s"><i class="fa fa-google-plus"></i></a></li>', esc_url( $gplus ) );
										}
									?>
									<?php 
										if( $linkedin ){
											printf( '<li><a href="%s"><i class="fa fa-linkedin"></i></a></li>', esc_url( $linkedin ) );
										}
									?>
									<?php 
										if( $youtube ){
											printf( '<li><a href="%s"><i class="fa fa-youtube"></i></a></li>', esc_url( $youtube ) );
										}
									?>
								</ul>
							</div>
						<?php endif;?>
					</div>
				</div>

				<?php if( $author_description = get_the_author_meta( 'description', $instructor ) ):?>
					<div class="ep-instructor-bio">
						<?php echo esc_html( $author_description ); ?>			
					</div>
				<?php endif;?>
			</div>
			<?php
		}
	}
}


/**
 * Adding the instructor tab
 */

add_filter( 'learn_press_course_tabs', 'ep_learn_press_course_instructor_tab', 5 );

if(!function_exists('ep_learn_press_course_instructor_tab')){
	function ep_learn_press_course_instructor_tab( $tabs ){

		$instructor_course_tab = cs_get_option('instructor_course_tab');

		if( $instructor_course_tab == true && !defined( 'LP_ADDON_CO_INSTRUCTOR_PATH' ) ){
			$tabs['instructor'] =  array(
				'title'    => esc_html__( 'Instructor', 'wp-education' ),
				'priority' => 30,
				'callback' => 'ep_course_instructor_tab_content'
			);
		}
		
		return $tabs;
	}
}


/**
 * Get post first category / tag
 */

if( !function_exists('get_post_first_category') ){
	function get_post_first_category ( $post_id, $taxonomy = null ){
		if( !$post_id ){
			$post_id = get_the_id();
		}

		if( $post_id &&  $taxonomy ){
			$terms = get_the_terms( $post_id, $taxonomy );
			$term_name = $term_link = '';
			if( $terms && !empty($terms) ){
				$term = array_shift($terms);
				$term_name = $term->name;
				$term_link = get_term_link($term->term_id);
			}
		}

		if( $term_name && $term_link ){
			return sprintf( '<a href="%s">%s</a>', esc_url( $term_link ), esc_html( $term_name ) );
		}else{
			return false;
		}
	}
}



/**
 * Course category
 */

if(!function_exists('educationpress_course_category')){
	function educationpress_course_category(){
		if( $first_cat = get_post_first_category( get_the_id(), 'course_category' ) ):
			?>
				<div class="course-categories">
					<label><?php esc_html_e( 'Categories', 'wp-education' ); ?></label>
					<div class="value">
						<span class="cat-links">
							<?php echo $first_cat;?>
						</span>
					</div>
				</div>
			<?php
		endif;
	}
}


/**
 * PHP 5.5 older version support
 */

if (! function_exists('array_column')) {
    function array_column(array $input, $columnKey, $indexKey = null) {
        $array = array();
        foreach ($input as $value) {
            if ( !array_key_exists($columnKey, $value)) {
                trigger_error("Key \"$columnKey\" does not exist in array");
                return false;
            }
            if (is_null($indexKey)) {
                $array[] = $value[$columnKey];
            }
            else {
                if ( !array_key_exists($indexKey, $value)) {
                    trigger_error("Key \"$indexKey\" does not exist in array");
                    return false;
                }
                if ( ! is_scalar($value[$indexKey])) {
                    trigger_error("Key \"$indexKey\" does not contain scalar value");
                    return false;
                }
                $array[$value[$indexKey]] = $value[$columnKey];
            }
        }
        return $array;
    }
}


/**
 * Single Course Information
 */

if(!function_exists('ep_course_info')){
	function ep_course_info(){
		global $post;
		$course = learn_press_get_course( $post->ID );
		$curriculums = $course->get_curriculum();

		$outputs = array();

		if( $curriculums && !empty($curriculums) ){
			foreach ( $curriculums as $section ) {
				foreach ( $section->items as $item ) {
					$outputs[] = json_decode(json_encode($item), True);;
				}
			}
		}

		$count_array = array_count_values( array_column( $outputs, 'post_type' ) );
		$count_lesson = $count_quiz = 0;

		if( array_key_exists('lp_lesson', $count_array) ){
			$count_lesson = $count_array['lp_lesson'];
		}
		if( array_key_exists('lp_quiz', $count_array) ){
			$count_quiz = $count_array['lp_quiz'];
		}

		$duration = get_post_meta( $post->ID, '_lp_duration', true );

		$skill_level = ep_get_post_meta( '_course_side_options', 'skill-level', 'all', true );
		$language = ep_get_post_meta( '_course_side_options', 'language', 'English', true );
		$retake_count = get_post_meta( $post->ID, '_lp_retake_count', true );
		if( !$retake_count ){
			$retake_count = esc_html__( 'N/A', 'wp-education' );
		}
		?>
		<?php do_action( 'ep_before_course_info' )?>
		<h3><?php echo apply_filters( 'ep_course_info_title', esc_html__( 'Course Features','wp-education' ) );?></h3>
		<ul>
			<li><i class="fa fa-files-o" aria-hidden="true"></i><span class="course-info-label"><?php esc_html_e('Lectures','wp-education' );?></span><span class="course-info-value"><?php echo esc_html( $count_lesson ); ?></span></li>
			<li><i class="fa fa-puzzle-piece" aria-hidden="true"></i><span class="course-info-label"><?php esc_html_e('Quizzes','wp-education' );?></span><span class="course-info-value"><?php echo esc_html( $count_quiz ); ?></span></li>
			<li><i class="fa fa-clock-o" aria-hidden="true"></i><span class="course-info-label"><?php esc_html_e('Duration','wp-education' );?></span><span class="course-info-value"><?php echo esc_html( $duration );?></span></li>
			<li><i class="fa fa-level-up" aria-hidden="true"></i><span class="course-info-label"><?php esc_html_e('Skill level','wp-education' );?></span><span class="course-info-value"><?php echo esc_html( $skill_level ); ?></span></li>
			<li><i class="fa fa-language" aria-hidden="true"></i><span class="course-info-label"><?php esc_html_e('Language','wp-education' );?></span><span class="course-info-value"><?php echo esc_html( $language ); ?></span></li>
			<li><i class="fa fa-undo" aria-hidden="true"></i><span class="course-info-label"><?php esc_html_e('Re-take course','wp-education' );?></span><span class="course-info-value"><?php echo esc_html( $retake_count ); ?></span></li>		
		</ul>
		<?php 
			/* Single Course Wishlist Button */
			if ( educationpress_plugin_active( 'learnpress-wishlist/learnpress-wishlist.php' ) ) {
				$addon_wishlist = LP_Addon_Wishlist::instance();
				$user  = learn_press_get_current_user();
				if ( !$user->has( 'enrolled-course', $course->id ) ){
					echo $addon_wishlist->wishlist_button();
				}
			}
		?>
		<?php do_action( 'ep_after_course_info' )?>
		<?php
	}
}


/**
 * Relative Courses
 */

if(!function_exists('educationpress_relative_courses')){
	function educationpress_relative_courses(){
		global $post;
		$course_category = $course_tag = array();
		$course_categories = $course_tags = '';
	    $categories = wp_get_post_terms( $post->ID, 'course_category' );
	    $tags = wp_get_post_terms( $post->ID, 'course_tag' );

	    if( $categories && !empty($categories) ){
	    	foreach ( $categories as $category ) {
	    		$course_category[] = $category->term_id;
	    	}
	    	$course_categories = implode(', ', $course_category);
	    }

	    if( $tags && !empty($tags) ){
	    	foreach ( $tags as $tag ) {
	    		$course_tag[] = $tag->term_id;
	    	}
	    	$course_tags = implode(', ', $course_tag);
	    }

		echo do_shortcode( '[ep_course shortcode_title="'.esc_html__( 'Relative Courses', 'wp-education' ).'" type="slider" items="2" desktopsmall="2" not_in="'.$post->ID.'"]' );

	}
}

/**
 * Remove Jetpack relative course
 */

function ep_related_course_jetpackme_remove() {
    if ( class_exists( 'Jetpack_RelatedPosts' ) && !is_singular( 'post' ) ) {
        $jprp = Jetpack_RelatedPosts::init();
        $callback = array( $jprp, 'filter_add_target_to_dom' );
        remove_filter( 'the_content', $callback, 40 );
    }
}
add_filter( 'wp', 'ep_related_course_jetpackme_remove', 20 );

/**
 * Remove Jetpack sharing
 */

add_filter( 'wp', 'ep_jptweak_remove_share', 20 );

function ep_jptweak_remove_share() {
	if( !is_singular( 'post' ) ){
		remove_filter( 'the_content', 'sharing_display', 19 );
    	remove_filter( 'the_excerpt', 'sharing_display', 19 );
	}
}


/**
 * course loop item before course meta
 */

if(!function_exists('ep_learn_press_courses_loop_item_before_meta')){
	function ep_learn_press_courses_loop_item_before_meta(){
		echo '<div class="ep-course-meta">';
	}
}


/**
 * course loop item after course meta
 */

if(!function_exists('educationpress_learn_press_courses_loop_item_after_meta')){
	function educationpress_learn_press_courses_loop_item_after_meta(){
		echo '</div>';
	}
}


/**
 * course loop item start
 */

if(!function_exists('educationpress_learn_press_before_course_item_figure')){
	function educationpress_learn_press_before_course_item_figure(){
		echo '<figure>';
	}
}

/**
 * course loop item end
 */

if(!function_exists('educationpress_learn_press_after_course_item_figure')){
	function educationpress_learn_press_after_course_item_figure(){
		echo '</figure>';
	}
}

/**
 * course loop item content start
 */

if(!function_exists('educationpress_learn_press_courses_loop_item_figcaption')){
	function educationpress_learn_press_courses_loop_item_figcaption(){
		echo '<figcaption>';
	}
}

/**
 * course loop item content end
 */

if(!function_exists('educationpress_learn_press_courses_loop_item_figcaption_end')){
	function educationpress_learn_press_courses_loop_item_figcaption_end(){
		echo '</figcaption>';
	}
}

/**
 * course loop item before thumbnail
 */

if(!function_exists('educationpress_learn_press_before_course_item_thumbnail')){
	function educationpress_learn_press_before_course_item_thumbnail(){
		echo '<div class="ep-course-thumb-area">';
	}
}

/**
 * course loop item after thumbnail
 */

if(!function_exists('educationpress_learn_press_after_course_item_thumbnail')){
	function educationpress_learn_press_after_course_item_thumbnail(){
		echo '</div>';
	}
}

/**
 * course loop item wishlist
 */

if(!function_exists('educationpress_learn_press_wishlist')){
	function educationpress_learn_press_wishlist(){
		if( cs_get_option( 'show_course_wishlist' ) == true && educationpress_plugin_active( 'learnpress-wishlist/learnpress-wishlist.php' ) ){
			$addon_wishlist = LP_Addon_Wishlist::instance();
			echo $addon_wishlist->wishlist_button();
		}
	}
}

/**
 * EP Before uesr profile tab
 */

if(!function_exists('educationpress_learn_press_before_user_profile_tabs')){
	function educationpress_learn_press_before_user_profile_tabs(){
		echo '<div class="col-lg-9 col-md-8">';
	}
}

/**
 * EP After uesr profile tab
 */

if(!function_exists('educationpress_learn_press_after_user_profile_tabs')){
	function educationpress_learn_press_after_user_profile_tabs(){
		echo '</div>';
	}
}


/**
 * Course loop short description
 */

if(!function_exists('educationpress_learn_press_courses_loop_item_short_description')){
	function educationpress_learn_press_courses_loop_item_short_description(){
		global $course, $post;
		$short_description = ep_get_post_meta( '_course_side_options', 'short_description', '', true, $post->ID );
		if( $short_description )
		echo '<div class="ep-course-description">'.wpautop( esc_html( apply_filters( 'ep_course_loop_short_description', $short_description ) ) ).'</div>';
	}
}


/**
 * Archive title filter
 */

add_filter( 'get_the_archive_title', 'educationpress_get_the_archive_title');

if(!function_exists('educationpress_get_the_archive_title')){
	function educationpress_get_the_archive_title( $title ) {
		$courses_page_id = get_option( 'learn_press_courses_page_id' );

		if ( is_category() ) {
			$title = single_cat_title( '', false );
		} elseif ( is_tag() ) {
			$title = single_tag_title( '', false );
		} elseif ( is_year() ) {
			$title = get_the_date( '', false );
		} elseif ( is_month() ) {
			$title = get_the_date( '', false );
		} elseif ( is_day() ) {
			$title = get_the_date( '', false );
		} elseif ( is_post_type_archive('lp_course') && $courses_page_id ) {
			$title = get_the_title( $courses_page_id );
		} elseif ( is_post_type_archive() ) {
			$title = post_type_archive_title( '', false );
		} elseif ( is_author() ) {
			$title = get_the_author();
		}elseif( is_tax('course_category') ){
			$title = single_term_title( '', false );
		}

		return $title;
	}
}


/**
 * Page Body Class
 */

add_filter('body_class', 'educationpress_page_body_classes');

if(!function_exists('educationpress_page_body_classes')){
	function educationpress_page_body_classes($classes) {
		$header_type = educationpress_cs_get_option( 'header_type', 'default' );
	    if( is_page() ){
	    	$page_layout = ep_get_post_meta( '_ep_page_side_options', 'page_layout', 'grid', true );
	    	$need_page_title = ep_get_post_meta( '_ep_page_side_options', 'need_page_title', true, true );
	    	$page_sidebar_enable = ep_get_post_meta( '_ep_page_side_options', 'page_sidebar_enable', false, true );
	    	$page_sidebar_position = ep_get_post_meta( '_ep_page_side_options', 'page_sidebar_position', 'no_sidebar', true );
	    	$header_transparent = ep_get_post_meta( '_ep_page_side_options', 'header_transparent', '', true );
	    	$main_content_margin_top = ep_get_post_meta( '_ep_page_side_options', 'main_content_margin_top', '', true );

			if( $page_layout && $page_layout == 'grid' ){
				$classes[] = 'ep-page-layout-grid';
			}elseif( $page_layout && $page_layout == 'full_screen' ) {
				$classes[] = 'ep-page-layout-full-width';
			}

			if( $need_page_title && $need_page_title = true ){
				$classes[] = 'ep-has-page-title';
			}else{
				$classes[] = 'ep-no-page-title';
			}

			if( $page_sidebar_enable && $page_sidebar_enable = true ){
				$classes[] = 'ep-has-page-sidebar';
			}else{
				$classes[] = 'ep-no-page-sidebar';
			}

			if( $page_sidebar_position && $page_sidebar_position == 'left' ){
				$classes[] = 'ep-page-left-sidebar';
			}elseif( $page_sidebar_position && $page_sidebar_position == 'right' ) {
				$classes[] = 'ep-page-right-sidebar';
			}

			if( $header_transparent || $header_type == 'transparent' ){
				$classes[] = 'ep-page-header-transparent';
			}else{
				$classes[] = 'ep-page-header-default';
			}

			if( $header_transparent && $main_content_margin_top ){
				$classes[] = 'ep-page-has-margin-top';
			}
	    }

	    if( !is_page() ){
	    	if( $header_type == 'transparent' ){
				$classes[] = 'ep-global-page-header-transparent';
			}else{
				$classes[] = 'ep-global-page-header-default';
			}
	    }

	    if ( is_post_type_archive('lp_course') || is_page( get_option( 'learn_press_courses_page_id' ) ) ) {
	        $classes[] = 'ep-course-archive';
	    }

	    return $classes;
	}
}


/**
 * Learn Press profile sub tab headings
 */

add_filter( 'learn_press_profile_tab_courses_subtabs', 'educationpress_learn_press_profile_tab_courses_subtabs' );

if(!function_exists('educationpress_learn_press_profile_tab_courses_subtabs')){
	function educationpress_learn_press_profile_tab_courses_subtabs( $subtabs ){

		$subtabs = array(
			'learning'  => esc_html__( 'Enrolled Courses', 'wp-education' ),
			'purchased' => esc_html__( 'Purchased Courses', 'wp-education' ),
			'finished'  => esc_html__( 'Finished Courses', 'wp-education' ),
			'own'       => esc_html__( 'Own Courses', 'wp-education' )
		);

		return $subtabs;
	}
}


/**
 * Show custom item in menu
 */

add_filter( 'wp_nav_menu_items', 'educationpress_show_cart_in_header', 10, 2 );

if(!function_exists('educationpress_show_cart_in_header')){
	function educationpress_show_cart_in_header( $items, $args ){

		if( educationpress_plugin_active( 'learnpress/learnpress.php' ) ){
			$ep_menu_cart_icon = cs_get_option( 'ep_menu_cart_icon' );
			$ep_menu_profile = cs_get_option( 'ep_menu_profile' );
			$ep_login_page = educationpress_cs_get_option( 'ep_login_page', '' );
			$ep_profile_page = educationpress_cs_get_option( 'ep_profile_page', '' );

			/* Show Profile in header menu */

			if ( $args->theme_location == 'primary' && $ep_menu_profile == true && $ep_profile_page != '' && $ep_login_page != '' ) {

				if( is_user_logged_in() ){
					$profile = '<li class="ep_profile_login_page ep-nav-menu-custom-item"><a href="'.esc_url( learn_press_user_profile_link() ).'"><span>'. esc_html( get_the_title( $ep_profile_page ) ) .'</span></a></li>';
				}else{
					$profile = '<li class="ep_profile_login_page ep-nav-menu-custom-item"><a href="'.esc_url( get_page_link( $ep_login_page ) ).'"><span>'. esc_html( get_the_title( $ep_login_page ) ) .'</span></a></li>';
				}
				
				$items = $items . $profile;
			}
		}

	    return $items;
	}
}


/**
 * After Login Redirect
 *
 * If user not admin and has course in cart, will be redirected to the cart page after login
 * If user not admin and has no course in cart, will be redirected to there profile page after login
 *
 */

add_filter( 'login_redirect', 'educationpress_after_login_redirect', 90, 3 );

if(!function_exists('educationpress_after_login_redirect')){
	function educationpress_after_login_redirect( $redirect_to, $request, $user ) {

		if ( isset( $user->roles ) && is_array( $user->roles ) && educationpress_plugin_active( 'learnpress/learnpress.php' ) && !is_admin() ){

			$user_profile = educationpress_author_profile_url( get_current_user_id() );

			if ( in_array( 'administrator', $user->roles ) ) {

				return $redirect_to;

			} elseif( $user_profile ) {

				return $user_profile;

			} else {

				return $redirect_to;

			}
		} else {

			return $redirect_to;

		}
	}
}



/**
 * course archive page course grid columns
 */

add_filter( 'ep_course_archive_grid_column', 'educationpress_course_archive_grid_column_setup' );

if(!function_exists('educationpress_course_archive_grid_column_setup')){
	function educationpress_course_archive_grid_column_setup( $classes ){

			$course_columns = cs_get_option('course_columns');

			switch ($course_columns) {
				case '2':
				$classes = 	'col-md-6';
					break;

				case '3':
				$classes = 	'col-md-4';
					break;	

				case '4':
				$classes = 	'col-md-3';
					break;

				case '5':
				$classes = 	'ep-col-md-5';
					break;

				case '6':
				$classes = 	'col-md-2';
					break;

				case '7':
				$classes = 	'ep-col-md-7';
					break;					
				
				default:
					$classes = 	'col-md-3';
					break;
			}
		

		return $classes;
	}
}



/**
 * Course Category list walker class
 */

if( !class_exists('EP_Course_Category_Walker') ) {
	class EP_Course_Category_Walker extends Walker_Category {
	 

		public function start_el( &$output, $category, $depth = 0, $args = array(), $id = 0 ) {
			/** This filter is documented in wp-includes/category-template.php */
			$cat_name = apply_filters(
				'list_cats',
				esc_attr( $category->name ),
				$category
			);

			// Don't generate an element if the category name is empty.
			if ( ! $cat_name ) {
				return;
			}

			$cat_count = '';
			$cat_icon = '';


			// Getting the category icon [ texonomoy meta ]
			$term_meta = get_option( "taxonomy_$category->term_id" );
			if ( ! empty( $term_meta['ep_cat_icons'] ) ) {
				$cat_icon = '<i class="'.esc_attr( $term_meta['ep_cat_icons'] ).'"></i>';
			}

			// Adding Post count 
			if ( ! empty( $args['show_count'] ) ) {
				$cat_count = '<span class="ep-cat-count">' . esc_html( number_format_i18n( $category->count ) ) . '</span>';
			}

	        
	        $link = '<a href="' . esc_url( get_term_link( $category ) ) . '" ';

			
			if ( $args['use_desc_for_title'] && ! empty( $category->description ) ) {
				$link .= 'title="' . esc_attr( strip_tags( apply_filters( 'category_description', $category->description, $category ) ) ) . '"';
			}

			$link .= '>'.$cat_icon;
			$link .= $cat_name . $cat_count. '</a>';



			if ( 'list' == $args['style'] ) {
				$output .= "\t<li";
				$css_classes = array(
					'cat-item',
					'cat-item-' . $category->term_id,
				);

				$termchildren = get_term_children( $category->term_id, $category->taxonomy );

	            if( count($termchildren)>0 ){
	                $css_classes[] =  'cat-item-have-child';
	            }

				if ( ! empty( $args['current_category'] ) ) {
					$_current_category = get_term( $args['current_category'], $category->taxonomy );
					if ( $category->term_id == $args['current_category'] ) {
						$css_classes[] = 'current-cat';
					} elseif ( $category->term_id == $_current_category->parent ) {
						$css_classes[] = 'ep-current-cat-parent';
					}
				}

				$css_classes = implode( ' ', apply_filters( 'category_css_class', $css_classes, $category, $depth, $args ) );

				$output .=  ' class="' . esc_attr($css_classes) . '"';
				$output .= ">$link\n";
			} else {
				$output .= "\t$link<br />\n";
			}
		}
	}
}



/**
 * Course archive navigation
 */

add_action( 'ep_before_course_archive_content', 'educationpress_course_archive_navigation' );

if( !function_exists('educationpress_course_archive_navigation') ){
	function educationpress_course_archive_navigation(){
		$navigation = educationpress_cs_get_option( 'course_navigation' );
		if( $navigation == true ):
			?>
			<div class="well well-sm clear ep-course-navigations">
				<?php do_action( 'educationpress_course_archive_navigation_item' );?>
			</div>
			<?php
		endif;
	}
}


/**
 * list & grid view
 */

add_action( 'educationpress_course_archive_navigation_item', 'educationpress_course_archive_navigation_list_grid_view', 15 );

if(!function_exists('educationpress_course_archive_navigation_list_grid_view')){
	function educationpress_course_archive_navigation_list_grid_view(){
		$navigation = educationpress_cs_get_option( 'course_navigation' );
		$list_grid = educationpress_cs_get_option( 'course_list_grid' );
		if( $navigation == true && $list_grid == true ):
			?>
			<div class="ep-list-grid-view pull-right">
				<a href="#" id="ep_course_list" class="btn btn-default btn-sm"><i class="fa fa-list" aria-hidden="true"></i>List</a>
				<a href="#" id="ep_course_grid" class="btn btn-default btn-sm"><i class="fa fa-th" aria-hidden="true"></i>Grid</a>
			</div>
			<?php
		endif;
	}
}


/**
 * Course filtering
 */

add_action( 'educationpress_course_archive_navigation_item', 'educationpress_course_archive_navigation_categories', 10 );

if(!function_exists('educationpress_course_archive_navigation_categories')){
	function educationpress_course_archive_navigation_categories() {
		$navigation = educationpress_cs_get_option( 'course_navigation' );
		$filtering = educationpress_cs_get_option( 'course_filtering' );
		if( $navigation == true && $filtering == true ){
			echo do_shortcode( '[searchandfilter taxonomies="course_category,course_tag"]' );
		}
	}
}



/**
 * EP Display rating stars
 */

if(!function_exists('educationpress_print_rating')){
	function educationpress_print_rating( $rate ) {

		?>
		<div class="ep-review-stars-wrapper">
			<ul class="ep-review-stars">
				<li><span class="fa fa-star"></span></li>
				<li><span class="fa fa-star"></span></li>
				<li><span class="fa fa-star"></span></li>
				<li><span class="fa fa-star"></span></li>
				<li><span class="fa fa-star"></span></li>
			</ul>
			<ul class="ep-review-stars fill" style="<?php echo esc_attr( 'width: ' . ( $rate * 20 ) . '%' ) ?>">
				<li><span class="fa fa-star"></span></li>
				<li><span class="fa fa-star"></span></li>
				<li><span class="fa fa-star"></span></li>
				<li><span class="fa fa-star"></span></li>
				<li><span class="fa fa-star"></span></li>
			</ul>
		</div>
		<?php
	}
}


/**
 * Display course ratings
 */

if(!function_exists('educationpress_course_ratings')){
	function educationpress_course_ratings() {

		if ( !educationpress_plugin_active( 'learnpress-course-review/learnpress-course-review.php' ) ) {
			return;
		}
		$course_id   = get_the_ID();
		$course_rate = learn_press_get_course_rate( $course_id );
		$ratings     = learn_press_get_course_rate_total( $course_id );
		?>
		<div class="course-review">
			<label><?php esc_html_e( 'Review', 'wp-education' ); ?></label>

			<div class="value">
				<?php educationpress_print_rating( $course_rate ); ?>
				<span><?php $ratings ? printf( _n( '(%1$s review)', '(%1$s reviews)', $ratings, 'wp-education' ), number_format_i18n( $ratings ) ) : esc_html_e( '(0 review)', 'wp-education' ); ?></span>
			</div>
		</div>
		<?php
	}
}



/**
 * Course enrolled students
 */

if( !function_exists('get_ep_course_enrolled_students') ){
	function get_ep_course_enrolled_students() {
		$course = LP()->global['course'];
		wp_enqueue_style( 'dashicons' );

		//$students = $course->get_users_enrolled();
		$students =  count( $course->get_students_list() );

		$output = '';

		if( !$students || $students == 0 ){
			$output = esc_html__( 'No student', 'wp-education' );
		}elseif( $students == 1 ){
			$output = $students . esc_html__( ' Student', 'wp-education' );
		}else{
			$output = $students . esc_html__( ' Students', 'wp-education' );
		}

		return '<span class="ep-course-students"><i class="dashicons dashicons-groups"></i>' . esc_html( $output ) . '</span>';
	}
}

if( !function_exists('ep_course_enrolled_students') ){
	function ep_course_enrolled_students(){
		echo get_ep_course_enrolled_students();
	}
}


/**
 * Display Course Author
 */

if( !function_exists('ep_course_author') ){
	function ep_course_author( $label = true, $name = true, $avatar = true  ) {
		?>
			<span class="ep-course-author-name">
				<?php if( $label ):?><span><?php esc_html_e( 'Teacher ', 'wp-education' ); ?></span><?php endif;?>
				<a href="<?php echo esc_url( educationpress_author_profile_url( get_the_author_meta('ID') ) ) ?>">
					<?php if( $name ):?><span><?php esc_html( the_author() ); ?></span><?php endif;?>
					<?php if( $avatar ):?><span class="ep-course-author-avatar"><?php echo get_avatar( get_the_author_meta( 'ID' ), 30 )?></span><?php endif;?>
				</a>
			</span>
		<?php
	}
}

/**
 * Display Course details link
 */

if( !function_exists('ep_course_details_btn') ){
	function ep_course_details_btn() {
		$label 	= apply_filters( 'ep_course_details_btn_text', educationpress_cs_get_option( 'enroll_button_text', esc_html__( 'Details', 'wp-education' ) ) );
		$user 	= learn_press_get_current_user();
		$course = LP()->global['course'];

		if( !$user->has( 'enrolled-course', $course->id ) ){
			learn_press_course_buttons();
		}else{
			?>
				<a href="<?php echo esc_url( get_the_permalink() ) ?>" class="btn btn-primary btn-lg"><?php echo esc_html( $label ) ?></a>
			<?php
		}
	}
}


/**
 * Display Course students & enrolle button
 */

if(!function_exists('ep_course_students_enrolle_button')){
	function ep_course_students_enrolle_button() {
		$course = LP()->global['course'];
		$user = learn_press_get_current_user();
		?>
			<div class="ep-course-price-n-join">
					<?php if( cs_get_option( 'show_course_price' ) == true && $price_html = $course->get_price_html() ): ?>
						<span class="ep-course-price"><?php echo $price_html; ?></span>
					<?php endif; ?>
				<?php 
					if( cs_get_option( 'show_course_enroll_btn' ) == true ){
						ep_course_details_btn();
					}
				?>
			</div>
		<?php
	}
}



/**
 * Process review
 */

add_action( 'learn_press_before_main_content', 'ep_saving_review' );

if ( !function_exists( 'ep_saving_review' ) ) {
	function ep_saving_review() {

		if ( !educationpress_plugin_active( 'learnpress-course-review/learnpress-course-review.php' ) ) {
			return;
		}

		if( is_singular( 'lp_course' ) ){
			$user_id     = get_current_user_id();
			$course_id   = isset ( $_POST['comment_post_ID'] ) ? $_POST['comment_post_ID'] : 0;
			$user_review = learn_press_get_user_rate( $course_id, $user_id );
			if ( !$user_review && $course_id ) {
				$review_title   = isset ( $_POST['ep-review-title'] ) ? $_POST['ep-review-title'] : 0;
				$review_content = isset ( $_POST['ep-review-content'] ) ? $_POST['ep-review-content'] : 0;
				$review_rate    = isset ( $_POST['ep-review-value'] ) ? $_POST['ep-review-value'] : 0;
				learn_press_add_course_review( array(
					'title'     => $review_title,
					'content'   => $review_content,
					'rate'      => $review_rate,
					'user_id'   => $user_id,
					'course_id' => $course_id
				) );
			}
		}
		
	}
}



/**
 * Add Inline custom css
 */

if(!function_exists('ep_add_inline_styles')){
	function ep_add_inline_styles() {
	    $logo_top_space = educationpress_cs_get_customize_option( 'logo_top_space', 18 );
	    $logo_bottom_space = educationpress_cs_get_customize_option( 'logo_bottom_space', 18 );
	    $menu_top_space = educationpress_cs_get_customize_option( 'menu_top_space', 35 );
	    $menu_bottom_space = educationpress_cs_get_customize_option( 'menu_bottom_space', 35 );
	    $menu_left_space = educationpress_cs_get_customize_option( 'menu_left_space', 15 );
	    $menu_right_space = educationpress_cs_get_customize_option( 'menu_right_space', 15 );
	    $ep_pre_header_bg = educationpress_cs_get_option( 'ep_pre_header_bg', '#25c1e7' );
	    $ep_pre_header_border_color = educationpress_cs_get_option( 'ep_pre_header_border_color', '#25c1e7' );
	    $ep_pre_header_color = educationpress_cs_get_option( 'ep_pre_header_color', '#ffffff' );
	    $footer_top_bottom_space = educationpress_cs_get_option( 'footer_top_bottom_space', 75 );
	    $footer_background_color = educationpress_cs_get_option( 'footer_background_color', '#2d3339' );
	    $footer_title_color = educationpress_cs_get_option( 'footer_title_color', '#ffffff' );
	    $footer_content_color = educationpress_cs_get_option( 'footer_content_color', '#999999' );
	    $footer_link_color = educationpress_cs_get_option( 'footer_link_color', '#ffffff' );
	    $bottom_bar_top_bottom_space = educationpress_cs_get_option( 'bottom_bar_top_bottom_space', 15 );
	    $bottom_bar_background_color = educationpress_cs_get_option( 'bottom_bar_background_color', '#23272d' );
	    $bottom_bar_text_color = educationpress_cs_get_option( 'bottom_bar_text_color', '#575c61' );
	    $bottom_bar_link_color = educationpress_cs_get_option( 'bottom_bar_link_color', '#ffffff' );
	    $course_slider_min_height = educationpress_cs_get_option( 'course_slider_min_height', 170 );
	    $site_content_margin_top = educationpress_cs_get_option( 'site_content_margin_top', 130 );
	    $ep_header_bg = educationpress_cs_get_option( 'ep_header_bg', '#ffffff' );
	    $ep_transparent_header_bg = educationpress_cs_get_option( 'ep_transparent_header_bg', 'rgba(0, 0, 0, 0.7)' );
	    $ep_default_menu_color = educationpress_cs_get_option( 'ep_default_menu_color', '#777777' );
	    $ep_default_menu_hover_color = educationpress_cs_get_option( 'ep_default_menu_hover_color', '#333333' );
	    $ep_transparent_menu_color = educationpress_cs_get_option( 'ep_transparent_menu_color', '#dadada' );
	    $ep_transparent_menu_hover_color = educationpress_cs_get_option( 'ep_transparent_menu_hover_color', '#ffffff' );
	    $ep_dropdown_menu_bg = educationpress_cs_get_option( 'ep_dropdown_menu_bg', '#ffffff' );
	    $ep_dropdown_menu_color = educationpress_cs_get_option( 'ep_dropdown_menu_color', '#333333' );
	    $ep_dropdown_menu_width = educationpress_cs_get_option( 'ep_dropdown_menu_width', 260 );
	    $ep_page_header_bg = educationpress_cs_get_option( 'ep_page_header_bg' );
	    $ep_custom_css_code = educationpress_cs_get_option( 'ep_custom_css_code' );


	    if( $ep_page_header_bg ){
	    	$ep_page_header_bg = wp_get_attachment_image_src( $ep_page_header_bg, 'full' );
	    	$ep_page_header_bg = $ep_page_header_bg[0];
	    }
	    if( is_page() && has_post_thumbnail() ){
			$ep_page_header_bg = get_the_post_thumbnail_url( get_the_id(), 'full' );
	    }

	    $ep_page_header_bg_color = educationpress_cs_get_option( 'ep_page_header_bg_color', 'rgba(45,51,57,0.4)' );
	    $ep_page_header_p_top = educationpress_cs_get_option( 'ep_page_header_p_top', 56 );
	    $ep_page_header_p_bottom = educationpress_cs_get_option( 'ep_page_header_p_bottom', 56 );
	    $ep_body_color = educationpress_cs_get_option( 'ep_body_color', '#666666' );
	    $ep_body_bg = educationpress_cs_get_option( 'ep_body_bg', '#f3f3f3' );
	    $body_font_size = educationpress_cs_get_option( 'body_font_size', 15 );
	    $body_line_height = educationpress_cs_get_option( 'body_line_height', 25 );

	    $custom_css = "
		    .logo-wrapper .custom-logo-link{
		        margin-top: {$logo_top_space}px;
		        margin-bottom: {$logo_bottom_space}px;
		    }
		    .ep-pre-header {
			    background: {$ep_pre_header_bg};
			    color: {$ep_pre_header_color};
			}
			.ep-pre-header a {
				color: {$ep_pre_header_color};
			}
		    @media (min-width: 768px){
			    .navbar.navbar-educationpress .navbar-nav>li>a {
			        padding-top: {$menu_top_space}px;
			        padding-bottom: {$menu_bottom_space}px;
			        padding-left: {$menu_left_space}px;
			        padding-right: {$menu_right_space}px;
			    }
			}
			.footer-widgets {
				padding-top: {$footer_top_bottom_space}px;
			    padding-bottom: {$footer_top_bottom_space}px;
			    background: {$footer_background_color};
			    color: {$footer_content_color};
			}
			.footer-widgets .widget-title {
				color: {$footer_title_color};
			}
			.footer-widgets a {
				color: {$footer_link_color};
			}
			.site-info {
				padding-top: {$bottom_bar_top_bottom_space}px;
			    padding-bottom: {$bottom_bar_top_bottom_space}px;
			    background: {$bottom_bar_background_color};
			    color: {$bottom_bar_text_color};
			}
			.site-info a {
				color: {$bottom_bar_link_color};
			}
			.ep-course-slider .ep-course-item figcaption {
			    min-height: {$course_slider_min_height}px;
			}
			body.ep-no-page-title.ep-page-has-margin-top.ep-page-header-transparent .site-content {
				margin-top: {$site_content_margin_top}px;
			}
			.navbar.navbar-educationpress {
				background: {$ep_header_bg};
			}
			body.page .navbar.navbar-educationpress.header-transparent .site-header-wrapper, body.ep-global-page-header-transparent .navbar.navbar-educationpress .site-header-wrapper {
				background: {$ep_transparent_header_bg}!important;
			}
			.navbar-default .navbar-nav>li>a {
				color: {$ep_default_menu_color};
			}
			.navbar-default .navbar-nav>li>a:focus, .navbar-default .navbar-nav>li>a:hover {
			    color: {$ep_default_menu_hover_color};
			}
			.header-transparent.navbar-educationpress .navbar-nav>li>a, body.ep-global-page-header-transparent .navbar-educationpress .navbar-nav>li>a, .logo-wrapper .site-title.site-title-transparent a {
			    color: {$ep_transparent_menu_color};
			}
			.header-transparent.navbar-educationpress .navbar-nav>li>a:hover, body.ep-global-page-header-transparent .navbar-educationpress .navbar-nav>li>a:hover {
			    color: {$ep_transparent_menu_hover_color};
			}
			.navbar-educationpress .ep-main-menu-wrapper .dropdown-menu {
				background: {$ep_dropdown_menu_bg};
			}
			.navbar-educationpress .ep-main-menu-wrapper .dropdown-menu li>a {
				color: {$ep_dropdown_menu_color};
			}
			@media (min-width: 768px){
				.navbar-educationpress .ep-main-menu-wrapper .dropdown-menu {
					min-width: {$ep_dropdown_menu_width}px;
				}
			}
			.educationpress-page-title-area:before {
				background: {$ep_page_header_bg_color};
			}
			.educationpress-page-title-area {
				padding-top: {$ep_page_header_p_top}px;
				padding-bottom: {$ep_page_header_p_bottom}px;
			}
			body {
				color: {$ep_body_color};
				background: {$ep_body_bg};
				line-height: {$body_line_height}px;
				font-size: {$body_font_size}px;
			}
		    ";

		if( $ep_page_header_bg ){
			$custom_css .= "
				.educationpress-page-title-area {
					background-image: url( $ep_page_header_bg );
				}
			";
		}


		$need_color_customizer = cs_get_option( 'need_color_customizer' );
		$ep_primary_color = cs_get_option( 'ep_primary_color' );
		$ep_primary_color_dark = cs_get_option( 'ep_primary_color_dark' );
		$ep_primary_color_light = cs_get_option( 'ep_primary_color_light' );
		if( $need_color_customizer == true ){
			$custom_css .= "#order_review_heading:before,#tribe-bar-form .tribe-bar-submit input[type=submit],#tribe-events .tribe-events-button,#tribe-events .tribe-events-button:hover,#tribe-events-content .tribe-events-tooltip h4,#tribe_events_filters_wrapper input[type=submit],.btn-primary,.button-primary,.cart_totals>h2:before,.cross-sells>h2:before,.entry-content>.container>.vc_row.ep_vc_row-background-primary,.entry-content>.vc_row.ep_vc_row-background-primary,.entry-tab-inner .ep-section-title:after,.ep-404-additional-info .widget-title:after,.ep-article.sticky figcaption:before,.ep-course-ajax-search-result-area li a:hover,.ep-course-category-item,.ep-course-grid .course-category,.ep-course-slider .course-category,.ep-course-slider.ep-default-width-slider.owl-theme .owl-controls .owl-buttons>div,.ep-course-slider.owl-theme .owl-controls .owl-page span,.ep-event-slider.owl-theme .owl-controls .owl-buttons>div,.ep-event-slider.owl-theme .owl-controls .owl-page span,.ep-feature-title h3:before,.ep-instructor-content-type-slider.owl-theme .owl-controls .owl-buttons>div,.ep-lms-statistics .ep-counter-number,.ep-nav-tabs>li>a::after,.ep-post-grid .ep-post-category,.ep-post-slider .ep-post-category,.ep-post-slider.owl-theme .owl-controls .owl-buttons>div,.ep-post-slider.owl-theme .owl-controls .owl-page span,.ep-pre-header,.ep-section-title.ep-section-title-border:after,.ep-social-icons ul li a,.ep-tab-pane-reviews .course-rating .detailed-rating .stars>div.bar .full_bar>div,.ep-testimonials.owl-theme .owl-controls .owl-page span,.ep-vc-theme-btn-primary-container .ep-vc-theme-btn-primary,.ep_cart_icon>a>span,.ep_course_category_list a:focus,.ep_course_category_list a:hover,.ep_course_category_list li.current-cat a,.ep_profile_login_page>a>span,.ep_theme_paignation .pager .active a,.ep_theme_paignation .pager .active span,.ep_theme_paignation .pager li>a:focus,.ep_theme_paignation .pager li>a:hover,.ep_vc_progress_bar.vc_progress_bar .vc_single_bar .vc_bar,.learn-press .course-meta>div .value.lp-progress-bar .lp-progress-value,.list-inline a:focus,.list-inline a:hover,.navbar.navbar-educationpress.ep-menu-hover-border .navbar-nav>li>a:after,.related.products>h2:before,.site-content .learn-press-pagination ul>li a:focus,.site-content .learn-press-pagination ul>li a:hover,.site-content .learn-press-pagination ul>li span,.site-content .lp-course-progress .lp-progress-bar .lp-progress-value,.slicknav_menu .slicknav_btn.slicknav_open,.slicknav_menu .slicknav_icon-bar,.tml-submit-wrap input[type=submit],.tribe-events-button,.tribe-events-button.tribe-active:hover,.tribe-events-button.tribe-inactive,.tribe-events-button:hover,.tribe-events-calendar td.tribe-events-present div[id*=tribe-events-daynum-],.tribe-events-calendar td.tribe-events-present div[id*=tribe-events-daynum-]>a,.tribe-events-calendar thead th,.tribe-events-day .tribe-events-day-time-slot h5:before,.tribe-events-list .tribe-events-event-cost span,.tribe-events-list-separator-month:before,.tribe-events-read-more,.up-sells.upsells.products>h2:before,.vc_tta-container .vc_tta-accordion.ep-vc-tta-accordion-theme-default .vc_tta-panel.vc_active .vc_tta-panel-heading,.vc_tta-container .vc_tta-accordion.ep-vc-tta-accordion-theme-default.vc_tta.vc_general .vc_tta-panel .vc_tta-panel-heading:hover,.widget-area .widget-title:after,.widget.widget_product_tag_cloud a:focus,.widget.widget_product_tag_cloud a:hover,.widget.widget_tag_cloud a:focus,.widget.widget_tag_cloud a:hover,.woocommerce #respond input#submit,.woocommerce #respond input#submit.alt,.woocommerce .widget_price_filter .ui-slider .ui-slider-handle,.woocommerce .widget_price_filter .ui-slider .ui-slider-range,.woocommerce a.button,.woocommerce a.button.alt,.woocommerce button.button,.woocommerce button.button.alt,.woocommerce div.product div.images .woocommerce-product-gallery__trigger,.woocommerce input.button,.woocommerce input.button.alt,.woocommerce nav.woocommerce-pagination ul li a:focus,.woocommerce nav.woocommerce-pagination ul li a:hover,.woocommerce nav.woocommerce-pagination ul li span.current,.woocommerce span.onsale,.woocommerce-Address-title>h3:before,.woocommerce-billing-fields>h3:before,.woocommerce-shipping-fields>h3:before,body #course-curriculum-popup #popup-main #popup-header,button.btn-primary,div.sharedaddy h3.sd-title:after,input[type=submit].btn-primary,input[type=submit].button-primary,input[type=submit].wpcf7-submit,input[type=button].btn-primary,input[type=reset].btn-primary{ background:{$ep_primary_color}}";

			$custom_css .= "#learn-press-course-curriculum .section .course-item a:focus,#learn-press-course-curriculum .section .course-item a:hover,.dropdown-menu>.active>a,.dropdown-menu>.active>a:focus,.dropdown-menu>.active>a:hover,.entry-footer .edit-link a:focus,.entry-footer .edit-link a:hover,.ep-archive-course-item .ep-course-price,.ep-article .entry-meta a:focus,.ep-article .entry-meta a:hover,.ep-article .entry-title a:focus,.ep-article .entry-title a:hover,.ep-course-grid .ep-course-price,.ep-course-item .course-title:focus,.ep-course-item .course-title:hover,.ep-course-search .ep-lms-stats>span i,.ep-course-slider .ep-course-price,.ep-event-grid .ep-event-price,.ep-event-slider .ep-event-price,.ep-features.ep-features-icon-primary-color .ep-feature-icon i,.ep-media-heading a:focus,.ep-media-heading a:hover,.ep-nav-tabs>li.active>a,.ep-nav-tabs>li>a:hover,.ep-post-meta a:hover,.ep_vc_row-color-white .ep-post-slider .ep-post-meta a:hover,.header-transparent.navbar-educationpress .navbar-nav>li.current-menu-ancestor>a,.learn-press-user-profile .learn-press-tabs-wrapper-x .learn-press-subtabs>li.current a,.logged-in-as a:focus,.logged-in-as a:hover,.nav-tabs>li.active>a,.nav-tabs>li.active>a:focus,.nav-tabs>li.active>a:hover,.navbar-educationpress .navbar-nav .current-menu-item.active>a,.navbar-educationpress .navbar-nav .current-menu-item.active>a:focus,.navbar-educationpress .navbar-nav .current-menu-item.active>a:hover,.navbar-educationpress .navbar-nav>.current-menu-parent>a,.navbar-educationpress .navbar-nav>.current-menu-parent>a:focus,.navbar-educationpress .navbar-nav>.current-menu-parent>a:hover,.site-content .learn-press-tabs .learn-press-nav-tabs .learn-press-nav-tab.active a,.slicknav_btn,.slicknav_menu .slicknav_btn.slicknav_open,.slicknav_menu .slicknav_btn.slicknav_open:active,.slicknav_menu .slicknav_btn.slicknav_open:focus,.widget a:focus,.widget a:hover,.woocommerce .product_meta a,.woocommerce .woocommerce-MyAccount-content a,.woocommerce div.product form.cart .reset_variations,.wpb-fp-filter li.active,a,body.ep-global-page-header-transparent .navbar-educationpress .navbar-nav>li.current-menu-ancestor>a,body.page.ep-has-page-title .navbar-educationpress .navbar-nav>li.current-menu-ancestor>a{ color:{$ep_primary_color}}";

			$custom_css .= ".btn-primary,.button-primary,.ep-404-additional-info .search-form .search-field:focus,.ep-course-navigations .usearchbtn:focus,.ep-course-navigations .usearchbtn:hover,.ep-course-navigations select:focus,.ep-list-grid-view .btn:focus,.ep-list-grid-view .btn:hover,.form-control:focus,.learn-press-user-profile .learn-press-tabs-wrapper-x .learn-press-subtabs>li.current,.navbar-educationpress .dropdown-menu,.site-content .learn-press-tabs .learn-press-nav-tabs .learn-press-nav-tab.active,.tml-submit-wrap input[type=submit],.vc_tta-container .vc_tta-accordion.ep-vc-tta-accordion-theme-default .vc_tta-panel.vc_active .vc_tta-panel-heading,.vc_tta-container .vc_tta-accordion.ep-vc-tta-accordion-theme-default.vc_tta.vc_general .vc_tta-panel .vc_tta-panel-heading:hover,.widget select:focus,.widget.widget_product_tag_cloud a,.widget.widget_tag_cloud a,.widget_search .search-field:focus,.woocommerce .widget_price_filter .ui-slider .ui-slider-handle,.wpb-fp-filter li.active,body #course-curriculum-popup #popup-main #popup-header,body.woocommerce div.product .woocommerce-tabs ul.tabs li.active,button.btn-primary,input[type=submit].btn-primary,input[type=submit].button-primary,input[type=submit].wpcf7-submit,input[type=range]:focus,input[type=date]:focus,input[type=month]:focus,input[type=week]:focus,input[type=time]:focus,input[type=datetime]:focus,input[type=datetime-local]:focus,input[type=color]:focus,input[type=button].btn-primary,input[type=reset].btn-primary,input[type=text]:focus,input[type=email]:focus,input[type=url]:focus,input[type=password]:focus,input[type=search]:focus,input[type=number]:focus,input[type=tel]:focus,select:focus,textarea:focus{ border-color:{$ep_primary_color} }";

			/* Dark */

			$custom_css .= "a:focus,a:hover{ color:{$ep_primary_color_dark} }";

			$custom_css .= "#tribe-bar-form .tribe-bar-submit input[type=submit]:focus,#tribe-bar-form .tribe-bar-submit input[type=submit]:hover,#tribe-events-content .tribe-events-calendar .mobile-active:hover,#tribe-events-content .tribe-events-calendar td.tribe-events-othermonth.mobile-active,#tribe-events-content .tribe-events-calendar td.tribe-events-othermonth.mobile-active div[id*=tribe-events-daynum-],#tribe-events-content .tribe-events-calendar td.tribe-events-othermonth.mobile-active div[id*=tribe-events-daynum-] a,#tribe-events-content .tribe-events-calendar td.tribe-events-present.mobile-active:hover,.btn-primary.active,.btn-primary.disabled.focus,.btn-primary.disabled:focus,.btn-primary.disabled:hover,.btn-primary:active,.btn-primary:active.focus,.btn-primary:active:focus,.btn-primary:active:hover,.btn-primary:focus,.btn-primary:hover,.btn-primary[disabled].focus,.btn-primary[disabled]:focus,.btn-primary[disabled]:hover,.button-primary:hover,.ep-course-slider.ep-default-width-slider.owl-theme .owl-controls .owl-buttons>div:hover,.ep-event-slider.owl-theme .owl-controls .owl-buttons>div:hover,.ep-instructor-content-type-slider.owl-theme .owl-controls .owl-buttons>div:hover,.ep-post-slider.owl-theme .owl-controls .owl-buttons>div:hover,.ep-social-icons ul li a:hover,.ep_profile_login_page>a:active>span,.ep_profile_login_page>a:focus>span,.ep_profile_login_page>a:hover>span,.open>.dropdown-toggle.btn-primary,.tml-submit-wrap input[type=submit]:focus,.tml-submit-wrap input[type=submit]:hover,.tribe-events-calendar .mobile-active div[id*=tribe-events-daynum-],.tribe-events-calendar .mobile-active div[id*=tribe-events-daynum-] a,.tribe-events-calendar td.mobile-active,.tribe-events-calendar td.tribe-events-present.mobile-active,.tribe-events-calendar td.tribe-events-present.mobile-active div[id*=tribe-events-daynum-],.tribe-events-calendar td.tribe-events-present.mobile-active div[id*=tribe-events-daynum-] a,.tribe-events-read-more:focus,.tribe-events-read-more:hover,.woocommerce #respond input#submit.alt:hover,.woocommerce #respond input#submit:hover,.woocommerce a.button.alt:hover,.woocommerce a.button:hover,.woocommerce button.button.alt:hover,.woocommerce button.button:hover,.woocommerce input.button.alt:hover,.woocommerce input.button:hover,body #course-curriculum-popup #popup-main #popup-header .popup-close:hover,body #course-curriculum-popup #popup-main #popup-header .sidebar-hide-btn:hover,body #course-curriculum-popup #popup-main #popup-header .sidebar-show-btn:hover,fieldset[disabled] .btn-primary.focus,fieldset[disabled] .btn-primary:focus,fieldset[disabled] .btn-primary:hover,input[type=submit].button-primary:hover,input[type=submit].wpcf7-submit:focus,input[type=submit].wpcf7-submit:hover{ background:{$ep_primary_color_dark}}"; 

			$custom_css .= ".ep-course-grid .course-category:before,.ep-course-slider .course-category:before,.ep-post-grid .ep-post-category:before,.ep-post-slider .ep-post-category:before{border-right-color:{$ep_primary_color_dark}}";

			$custom_css .= ".btn-primary.active,.btn-primary:active,.btn-primary:active.focus,.btn-primary:active:focus,.btn-primary:active:hover,.btn-primary:focus,.btn-primary:hover,.mc4wp-form-fields input[type=text]:focus,.open>.dropdown-toggle.btn-primary,.tribe-events-calendar thead th,.tribe-events-list .tribe-events-event-cost span,.widget_search .search-field:focus,body #course-curriculum-popup #popup-main #popup-header .popup-menu{border-color:{$ep_primary_color_dark}}";

			/* Light */
			
			$custom_css .= ".learn-press-user-profile .learn-press-tabs-wrapper-x .learn-press-subtabs>li a:hover,.learn-press-user-profile .learn-press-tabs-wrapper-x .learn-press-subtabs>li.current a,.learn-press-user-profile .learn-press-tabs.ep-user-profile-menu>li.current a,.learn-press-user-profile .learn-press-tabs.ep-user-profile-menu>li>a:hover,.woocommerce-MyAccount-navigation ul li a:hover,.woocommerce-MyAccount-navigation ul li.is-active a{background:{$ep_primary_color_light}}";
			$custom_css .= ".learn-press-user-profile .learn-press-tabs.ep-user-profile-menu>li a,.learn-press-user-profile .learn-press-tabs.ep-user-profile-menu>li:last-child a,.woocommerce-MyAccount-navigation ul li a{border-color:{$ep_primary_color_light}}";
		}

		if( $ep_custom_css_code ){
			$custom_css .= $ep_custom_css_code;
		}

		$custom_css = apply_filters( 'ep_custom_css', $custom_css );    

	    wp_add_inline_style( 'educationpress-custom', $custom_css );

	}
}
add_action( 'wp_enqueue_scripts', 'ep_add_inline_styles' );


/**
 * Custom JS
 */
if(!function_exists('ep_add_inline_js')){
	function ep_add_inline_js() {

		$ep_custom_js_code = educationpress_cs_get_option( 'ep_custom_js_code' );

		wp_enqueue_script( 'educationpress-main', get_template_directory_uri() . '/js/main.js', array('jquery'), '1.0', true );

		wp_add_inline_script( 'educationpress-main', $ep_custom_js_code );
	}
}
add_action( 'wp_enqueue_scripts', 'ep_add_inline_js' );




/**
 * Course ID column
 */

add_filter( 'manage_lp_course_posts_columns', 'ep_add_course_id_column', 5 );
add_action( 'manage_lp_course_posts_custom_column', 'ep_course_id_column_content', 5, 2 );
add_filter( 'manage_post_posts_columns', 'ep_add_course_id_column', 5 );
add_action( 'manage_post_posts_custom_column', 'ep_course_id_column_content', 5, 2 );

if(!function_exists('ep_add_course_id_column')){
	function ep_add_course_id_column( $columns ) {
	   $columns['course_id'] = esc_html__( 'ID', 'wp-education' );
	   return $columns;
	}
}

if(!function_exists('ep_course_id_column_content')){
	function ep_course_id_column_content( $column, $id ) {
	  if( 'course_id' == $column ) {
	    echo $id;
	  }
	}
}


/**
 * Course Category ID Column
 */


add_filter('manage_edit-course_category_columns', 'ep_add_course_category_id_column', 5);
add_action('manage_course_category_custom_column', 'ep_add_course_category_id_column_content', 5, 3);
add_filter('manage_edit-category_columns', 'ep_add_course_category_id_column', 5);
add_action('manage_category_custom_column', 'ep_add_course_category_id_column_content', 5, 3);

if(!function_exists('ep_add_course_category_id_column')){
	function ep_add_course_category_id_column($defaults) {
		$defaults['course_category_ids'] = esc_html__( 'ID', 'wp-education' );
		return $defaults;
	}
}

if(!function_exists('ep_add_course_category_id_column_content')){
	function ep_add_course_category_id_column_content($value, $column_name, $id) {
		if( $column_name == 'course_category_ids' ) {
			echo (int)$id;
		}
	}
}


/**
 * Course Tag ID Column
 */


add_filter('manage_edit-course_tag_columns', 'ep_add_course_tag_id_column', 5);
add_action('manage_course_tag_custom_column', 'ep_add_course_tag_id_column_content', 5, 3);
add_filter('manage_edit-post_tag_columns', 'ep_add_course_tag_id_column', 5);
add_action('manage_post_tag_custom_column', 'ep_add_course_tag_id_column_content', 5, 3);

if(!function_exists('ep_add_course_tag_id_column')){
	function ep_add_course_tag_id_column($defaults) {
		$defaults['course_tag_ids'] = esc_html__( 'ID', 'wp-education' );
		return $defaults;
	}
}

if(!function_exists('ep_add_course_tag_id_column_content')){
	function ep_add_course_tag_id_column_content($value, $column_name, $id) {
		if( $column_name == 'course_tag_ids' ) {
			echo (int)$id;
		}
	}
}



/**
 * Count Published Course
 */

if(!function_exists('ep_wp_count_published_posts')){
	function ep_wp_count_published_posts( $post_type ){

		$count_posts = wp_count_posts( $post_type );

		if( $count_posts->publish ){
			return $count_posts->publish;
		}else {
			return 0;
		}
	}
}


/**
 * Count User by there role
 */

if(!function_exists('ep_wp_count_users_by_role')){
	function ep_wp_count_users_by_role( $role ){

		$users = get_users( array( 'role' => $role ) );

		if( $users && !empty( $users ) ){
			return count($users);
		}else{
			return 0;
		}
	}
}

/**
 * EP count students
 */

if(!function_exists('ep_count_students')){
	function ep_count_students( $status ){
		
		global $wpdb;
		$table = $wpdb->base_prefix.'learnpress_user_items';
		$count_students = $wpdb->get_var( 
			$wpdb->prepare( "SELECT COUNT(*) FROM $table WHERE status = %d", $status ) 
		);

		if( $count_students && !empty($count_students) ){

			return $count_students;
		}

	}
}



/**
 * LMS Process Search
 */

add_filter('template_include', 'ep_course_search_template_chooser'); 

if(!function_exists('ep_course_search_template_chooser')){
	function ep_course_search_template_chooser( $template ){    
		global $wp_query;   
		$post_type = get_query_var('post_type');   
		if( $wp_query->is_search && $post_type == 'lp_course' ){
			return locate_template('course-search.php');
		}

		return $template;   
	}
}



/**
 * Footer Bottom Bar
 */

add_action( 'educationpress_footer_bottom_bar', 'ep_footer_bottom_bar' );

if(!function_exists('ep_footer_bottom_bar')){
	function ep_footer_bottom_bar(){
		$menu = wp_nav_menu( array(
		    'menu'              => 'footer',
		    'theme_location'    => 'footer',
		    'depth'             => 1,
		    'container'         => '',
		    'menu_class'        => 'ep-footer-menu',
		    'fallback_cb'		=> false,
		    'echo'				=> false,
		));
		$footer_text = cs_get_option('footer_text');
		if( $footer_text || $menu ):
			?>
				<div class="site-info">
					<div class="<?php echo esc_attr( apply_filters( 'educationpress_footer_site_info_container_class', 'container' ) ); ?>">
						<div class="row">
							<?php if ( $footer_text ):?>
								<div class="col-md-7 col-sm-12">
									<?php echo wpautop( $footer_text ); ?>
								</div>
							<?php endif;?>
							<?php if ( $menu):?>
								<div class="col-md-5 col-sm-12 text-right">
									<?php echo $menu; ?>
								</div>
							<?php endif;?>
						</div>
					</div>
				</div><!-- .site-info -->
			<?php
		endif;
	}
}


/**
 * WordPress Bootstrap pagination
 */

if( !function_exists('ep_wp_numeric_pagination') ):
    function ep_wp_numeric_pagination( $args = array() ) {
        
        $defaults = array(
            'range'           => 4,
            'custom_query'    => FALSE,
            'previous_string' => '<i class="fa fa-angle-left"></i>',
            'next_string'     => '<i class="fa fa-angle-right"></i>',
            'before_output'   => '<nav class="ep_theme_paignation"><ul class="pager">',
            'after_output'    => '</ul></nav>'
        );
        
        $args = wp_parse_args( 
            $args, 
            apply_filters( 'wp_bootstrap_pagination_defaults', $defaults )
        );
        
        $args['range'] = (int) $args['range'] - 1;
        if ( !$args['custom_query'] )
            $args['custom_query'] = @$GLOBALS['wp_query'];
        $count = (int) $args['custom_query']->max_num_pages;
        $page  = intval( get_query_var( 'paged' ) );
        $ceil  = ceil( $args['range'] / 2 );
        
        if ( $count <= 1 )
            return FALSE;
        
        if ( !$page )
            $page = 1;
        
        if ( $count > $args['range'] ) {
            if ( $page <= $args['range'] ) {
                $min = 1;
                $max = $args['range'] + 1;
            } elseif ( $page >= ($count - $ceil) ) {
                $min = $count - $args['range'];
                $max = $count;
            } elseif ( $page >= $args['range'] && $page < ($count - $ceil) ) {
                $min = $page - $ceil;
                $max = $page + $ceil;
            }
        } else {
            $min = 1;
            $max = $count;
        }
        
        $echo = '';
        $previous = intval($page) - 1;
        $previous = esc_attr( get_pagenum_link($previous) );
        
        if ( $previous && (1 != $page) )
        	$echo .= sprintf ( '<li><a href="%s" title="%s">%s</a></li>', esc_url( $previous ), esc_html__( 'previous', 'wp-education' ), $args['previous_string'] );
        
        if ( !empty($min) && !empty($max) ) {
            for( $i = $min; $i <= $max; $i++ ) {
                if ($page == $i) {
                    $echo .= sprintf ( '<li class="active"><span class="active">%s</span></li>', esc_html( str_pad( (int)$i, 2, '0', STR_PAD_LEFT ) ) );
                } else {
                    $echo .= sprintf( '<li><a href="%s">%002d</a></li>', esc_attr( get_pagenum_link($i) ), $i );
                }
            }
        }
        
        $next = intval($page) + 1;
        $next = esc_attr( get_pagenum_link($next) );
        if ($next && ($count != $page) )
        	$echo .= sprintf ( '<li><a href="%s" title="%s">%s</a></li>', esc_url( $next ), esc_html__( 'next', 'wp-education' ), $args['next_string'] );
        
        if ( isset($echo) )
            echo $args['before_output'] . $echo . $args['after_output'];
    }
endif;


/**
 * Pagination RTL support
 */

add_filter( 'wp_bootstrap_pagination_defaults', 'ep_pagination_rtl_support' );

if(!function_exists('ep_pagination_rtl_support')){
	function ep_pagination_rtl_support($args){
		if( is_rtl() ){
			$args['next_string'] 		= '<i class="fa fa-angle-left"></i>';
			$args['previous_string'] 	= '<i class="fa fa-angle-right"></i>';
		}
		return $args;
	}
}

/**
 * WooCommerce Pagination RTL support
 */

add_filter( 'woocommerce_pagination_args', 'ep_woocommerce_pagination_rtl_support' );

if(!function_exists('ep_woocommerce_pagination_rtl_support')){
	function ep_woocommerce_pagination_rtl_support($args){
		if( !is_rtl() ){
			$args['next_text'] 	= '<i class="fa fa-angle-right"></i>';
			$args['prev_text'] 	= '<i class="fa fa-angle-left"></i>';
		}else{
			$args['next_text'] 	= '<i class="fa fa-angle-left"></i>';
			$args['prev_text'] 	= '<i class="fa fa-angle-right"></i>';
		}
		return $args;
	}
}


/**
 * Link Pages Bootstrap
 * @author toscha
 * @link http://wordpress.stackexchange.com/questions/14406/how-to-style-current-page-number-wp-link-pages
 * @param  array $args
 * @return void
 * Modification of wp_link_pages() with an extra element to highlight the current page.
 */

if( !function_exists('ep_bootstrap_link_pages') ):
	function ep_bootstrap_link_pages( $args = array () ) {
	    $defaults = array(
			'before' => '<nav class="ep_theme_paignation"><ul class="pager">',
			'after' => '</ul></nav>',
			'before_link' => '<li>',
			'after_link' => '</li>',
			'current_before' => '<li class="active">',
			'current_after' => '</li>',
	        'link_before' => '',
	        'link_after'  => '',
	        'pagelink'    => '%',
	        'echo'        => 1
	    );
	    $r = wp_parse_args( $args, $defaults );
	    $r = apply_filters( 'wp_link_pages_args', $r );
	    extract( $r, EXTR_SKIP );
	    global $page, $numpages, $multipage, $more, $pagenow;
	    if ( ! $multipage )
	    {
	        return;
	    }
	    $output = $before;
	    for ( $i = 1; $i < ( $numpages + 1 ); $i++ )
	    {
	        $j       = str_replace( '%', $i, $pagelink );
	        $output .= ' ';
	        if ( $i != $page || ( ! $more && 1 == $page ) )
	        {
	            $output .= "{$before_link}" . _wp_link_page( $i ) . "{$link_before}{$j}{$link_after}</a>{$after_link}";
	        }
	        else
	        {
	            $output .= "{$current_before}{$link_before}<a>{$j}</a>{$link_after}{$current_after}";
	        }
	    }
	    print $output . $after;
	}
endif;



/**
 * Excerpt bracket
 */

if(!function_exists('ep_ep_excerpt_more')){
	function ep_ep_excerpt_more( $more ) {
	    return '&#8230;';
	}
}
add_filter( 'excerpt_more', 'ep_ep_excerpt_more' );


/**
 * Post Navigation add class
 */

if(!function_exists('ep_construct_post_nav_attr')){
	function ep_construct_post_nav_attr($matches) {

	  $ret = 'rel="'. esc_attr( $matches[1] ) .'" class="btn btn-primary" ';

	  return $ret;
	}
}

if(!function_exists('ep_add_attr_to_post_nav_links')){
	function ep_add_attr_to_post_nav_links( $link ) {
	  return preg_replace_callback( '/rel="([^"]+)"/', 'ep_construct_post_nav_attr', $link );
	}
}
add_filter( 'next_post_link', 'ep_add_attr_to_post_nav_links' );
add_filter( 'previous_post_link', 'ep_add_attr_to_post_nav_links' );

/**
 * Comment navigation add class
 */

add_filter('next_comments_link_attributes', 'ep_comments_link_attributes');
add_filter('previous_comments_link_attributes', 'ep_comments_link_attributes');

if(!function_exists('ep_comments_link_attributes')){
	function ep_comments_link_attributes() {
	    return 'class="btn btn-primary"';
	}
}



/**
 * Comment list walker
 */

/**
 * A custom WordPress comment walker class to implement the Bootstrap 3 Media object in wordpress comment list.
 *
 * @package     WP Bootstrap Comment Walker
 * @version     1.0.0
 * @author      Edi Amin <to.ediamin@gmail.com>
 * @license     http://opensource.org/licenses/gpl-2.0.php GPL v2 or later
 * @link        https://github.com/ediamin/wp-bootstrap-comment-walker
 */

if( !class_exists('EP_Bootstrap_Comment_Walker') ){
	class EP_Bootstrap_Comment_Walker extends Walker_Comment {
		/**
		 * Output a comment in the HTML5 format.
		 *
		 * @access protected
		 * @since 1.0.0
		 *
		 * @see wp_list_comments()
		 *
		 * @param object $comment Comment to display.
		 * @param int    $depth   Depth of comment.
		 * @param array  $args    An array of arguments.
		 */
		protected function html5_comment( $comment, $depth, $args ) {
			$tag = ( 'div' === $args['style'] ) ? 'div' : 'li';
			?>		
			<<?php echo $tag; ?> id="comment-<?php comment_ID(); ?>" <?php comment_class( $this->has_children ? 'parent ep-media' : 'ep-media' ); ?>>

				<?php if ( 0 != $args['avatar_size'] ): ?>
				<div class="ep-media-left">
					<a href="<?php echo esc_url( get_comment_author_url() ); ?>" class="ep-media-object">
						<?php echo get_avatar( $comment, $args['avatar_size'] ); ?>
					</a>
				</div>
				<?php endif; ?>

				<div class="ep-media-body">

					<h4 class="ep-media-heading">
						<?php echo get_comment_author_link(); ?>
					
						<span class="comment-metadata">
							<a href="<?php echo esc_url( get_comment_link( $comment->comment_ID, $args ) ); ?>">
								<time datetime="<?php esc_attr( comment_time( 'c' ) ); ?>">
									<?php printf( esc_html_x( '%1$s at %2$s', '1: date, 2: time', 'wp-education' ), get_comment_date(), get_comment_time() ); ?>
								</time>
							</a>
						</span><!-- .comment-metadata -->
					</h4><!-- .ep-media-heading -->

					<?php if ( '0' == $comment->comment_approved ) : ?>
					<p class="comment-awaiting-moderation label label-info"><?php esc_html_e( 'Your comment is awaiting moderation.', 'wp-education' ); ?></p>
					<?php endif; ?>				

					<div class="comment-content">
						<?php comment_text(); ?>
					</div><!-- .comment-content -->
					
					<ul class="list-inline">
						<?php edit_comment_link( esc_html__( 'Edit', 'wp-education' ), '<li class="edit-link">', '</li>' ); ?>

						<?php
							comment_reply_link( array_merge( $args, array(
								'add_below' => 'div-comment',
								'depth'     => $depth,
								'max_depth' => $args['max_depth'],
								'before'    => '<li class="reply-link">',
								'after'     => '</li>'
							) ) );	
						?>

					</ul>

				</div>		
			<?php
		}	
	}
}




/**
 * Show Resize images
 * 
 * $thumb_id : thumbnail id, integer
 * $width : image width, integer
 * $height : image height, integer
 * $crop : image crop, boolean, default - true
 * $alt : image alt, string
 */


if(!function_exists('ep_get_ep_aq_resize_thumbnail')){
	function ep_get_ep_aq_resize_thumbnail( $width, $height, $thumb_id = null, $crop = null, $alt = null ){
		if( $thumb_id == null ){
			$thumb_id = get_post_thumbnail_id();
		}
		if( $crop == null ){
			$crop = true;
		}
		if( $alt != null ){
			$alt = get_the_title();
		}
		
		$img_url = wp_get_attachment_url( $thumb_id, 'full' );
		$resize_img_url = ep_aq_resize( $img_url, $width, $height, $crop );

		if( $resize_img_url ){
			return sprintf( '<img src="%s"'.( $alt ? ' alt="%s"' : '' ).'>', esc_url( $resize_img_url ), esc_html( $alt ) );
		}

	}
}


/**
 * Show Course Category Icon
 * 
 * $term_id : Category ID
 */

if(!function_exists('ep_course_category_icon')){
	function ep_course_category_icon( $term_id ) {
		$term_meta = get_option( "taxonomy_$term_id" );
		if ( ! empty( $term_meta['ep_cat_icons'] ) ) {
			echo '<i class="'. esc_attr( $term_meta['ep_cat_icons'] ) .'"></i>';
		}
	}
}


/**
 * Show Course Category Description
 * 
 * $term_id : Category ID
 */

if(!function_exists('ep_course_category_description')){
	function ep_course_category_description( $term_id ) {
		$description = term_description( $term_id );
		if ( $description ) {
			echo '<span class="ep-course-category-description">'. esc_html( $description ) .'</span>';
		}
	}
}



/**
 * LP Cart image resize
 */

add_filter( 'learn_press_cart_item_thumbnail', 'ep_learn_press_cart_item_thumbnail', 10, 2 );

if(!function_exists('ep_learn_press_cart_item_thumbnail')){
	function ep_learn_press_cart_item_thumbnail( $image, $cart_item ){
		$course_id = $cart_item['item_id'];
		$thumb_id = get_post_thumbnail_id( $course_id );
		$resize_image = ep_get_ep_aq_resize_thumbnail( 100, 90, $thumb_id );
		return $resize_image;
	}
}


/**
 * Course Ajax Search
 */

add_action('wp_ajax_nopriv_ep_ajax_course_search','ep_ajax_course_search');
add_action('wp_ajax_ep_ajax_course_search','ep_ajax_course_search');

if(!function_exists('ep_ajax_course_search')){
	function ep_ajax_course_search(){
		$args = array (
			'post_type' 		=> 'lp_course',
			'post_status' 		=> 'publish',
			'order' 			=> 'DESC',
			'orderby' 			=> 'date',
			's' 				=> $_POST['term'],
			'posts_per_page' 	=> apply_filters( 'ep_course_search_number_of_post', 10 ),
		);
		 
		$query = new WP_Query( $args );
		 
		if($query->have_posts()){
			echo '<ul>';
				while ($query->have_posts()) {
					$query->the_post();
					printf( '<li><a href="%s">%s</a></li>', esc_url( get_the_permalink() ), esc_html( get_the_title() ) );
				}
			echo '</ul>';
		}else{
			printf( '<li><a href="#">%s</a></li>', esc_html__( 'No result found.', 'wp-education' ) );
		}

		wp_reset_postdata();
		exit;
	}
}


/**
 * Define home url for ajax course search
 */

if(!function_exists('educationpress_ajax_course_search_base')){
	function educationpress_ajax_course_search_base(){
		?>
			<script type="text/javascript">var ep_home_url = "<?php echo esc_url( home_url() ) ?>";</script>
		<?php
	}
}



/**
 *  Author bio
 */

if ( ! function_exists( 'ep_get_author_bio' ) ) :
function ep_get_author_bio() {
    ?>
    <div class="ep-author-bio">
    	<div class="row">
	        <div class="ep-author-avatar col-sm-3">
	            <?php echo get_avatar( get_the_author_meta( 'user_email' ), 320 ); ?>
	        </div>
	        <div class="ep-author-comment col-sm-9">
	            <h3 class="ep-author-name"><?php echo esc_html( get_the_author() ); ?></h3>
	            <?php echo wpautop( esc_html( get_the_author_meta( 'description' ) ) ); ?>
	            <?php ep_get_instructor_social_icons( get_the_author_meta('ID'), 'small' ); ?>
	        </div>
        </div>
    </div>
    <?php
}
endif;



/**
 * Required Plugins
 */

add_action( 'tgmpa_register', 'ep_theme_register_required_plugins' );

if(!function_exists('ep_theme_register_required_plugins')){
	function ep_theme_register_required_plugins() {

		$plugins = array(
			array(
				'name'               => esc_html__( 'WP Education CPT and Shortcode', 'wp-education' ),
				'slug'               => 'wp-education-cpt-n-shortcode',
				'source'             => get_template_directory() . '/lib/plugins/wp-education-cpt-n-shortcode.zip',
				'required'           => true,
				'version'            => '1.02',
			),
			array(
				'name'               => esc_html__( 'Visual Composer', 'wp-education' ),
				'slug'               => 'js_composer',
				'source'             => get_template_directory() . '/lib/plugins/visual-composer.zip',
				'required'           => true,
				'version'            => '5.2.1',
			),
			array(
				'name'      => esc_html__( 'LearnPress - WordPress LMS Plugin', 'wp-education' ),
				'slug'      => 'learnpress',
				'required'  => true,
			),
			array(
				'name'      => esc_html__( 'LearnPress - Course Review', 'wp-education' ),
				'slug'      => 'learnpress-course-review',
				'required'  => false,
			),
			array(
				'name'      => esc_html__( 'LearnPress Courses Wishlist', 'wp-education' ),
				'slug'      => 'learnpress-wishlist',
				'required'  => false,
			),
			array(
				'name'      => esc_html__( 'LearnPress Prerequisite Courses', 'wp-education' ),
				'slug'      => 'learnpress-prerequisites-courses',
				'required'  => false,
			),
			array(
				'name'      => esc_html__( 'LearnPress Export/Import Courses', 'wp-education' ),
				'slug'      => 'learnpress-import-export',
				'required'  => false,
			),
			array(
				'name'      => esc_html__( 'Theme My Login', 'wp-education' ),
				'slug'      => 'theme-my-login',
				'required'  => false,
			),
			array(
				'name'      => esc_html__( 'MailChimp for WordPress', 'wp-education' ),
				'slug'      => 'mailchimp-for-wp',
				'required'  => false,
			),
			array(
				'name'      => esc_html__( 'Search & Filter', 'wp-education' ),
				'slug'      => 'search-filter',
				'required'  => false,
			),
			array(
				'name'      => esc_html__( 'Contact Form 7', 'wp-education' ),
				'slug'      => 'contact-form-7',
				'required'  => false,
			),
			array(
				'name'      => esc_html__( 'WooCommerce', 'wp-education' ),
				'slug'      => 'woocommerce',
				'required'  => false,
			),
			array(
				'name'      => esc_html__( 'The Events Calendar', 'wp-education' ),
				'slug'      => 'the-events-calendar',
				'required'  => false,
			),
			array(
				'name'      => esc_html__( 'One Click Demo Import', 'wp-education' ),
				'slug'      => 'one-click-demo-import',
				'required'  => false,
			),
		);

		$config = array(
			'id'           => 'wp-education-theme',
			'default_path' => '',
			'menu'         => 'tgmpa-install-plugins',
			'parent_slug'  => 'themes.php',
			'capability'   => 'edit_theme_options',
			'has_notices'  => true,
			'dismissable'  => true,
			'dismiss_msg'  => '',
			'is_automatic' => false,
			'message'      => '',
		);
		tgmpa( $plugins, $config );
	}
}


/**
 * Demo Installer
 * 
 * Using the plugin : https://wordpress.org/plugins/one-click-demo-import/
 *
 * Documentation : http://proteusthemes.github.io/one-click-demo-import/
 */

if(!function_exists('ep_import_theme_demo_files')){
	function ep_import_theme_demo_files() {
	  return array(
	    array(
	      'import_file_name'             => esc_html__( 'Demo Import', 'wp-education' ),
	      'local_import_file'            => trailingslashit( get_template_directory() ) . 'lib/demo-data/demo-content.xml',
	      'local_import_widget_file'     => trailingslashit( get_template_directory() ) . 'lib/demo-data/widgets.json',
	      'local_import_customizer_file' => trailingslashit( get_template_directory() ) . 'lib/demo-data/customizer.dat',
	      'import_notice'                => esc_html__( 'After you import this demo, you will have to setup the slider separately.', 'wp-education' ),
	    )
	  );
	}
}

add_filter( 'pt-ocdi/import_files', 'ep_import_theme_demo_files' );